CAplus Core Journal Coverage List | CAS
Description: List of journal titles, abbreviations, and CODENs for the core list of journal publications covered by CAS. This is not the full list of covered publications.

downloaded from: https://www.cas.org/support/documentation/references/corejournals september 2021
Skip to main content

# Support

CAS provides abstracts of articles, and indexes bibliographic, substance, and reaction information from key scientific journals such as those shown below. This information may appear within days of article publication.

The journal list below is sorted alphabetically by the full title and also includes the journal abbreviation and CODEN. This is not the full list of publications covered by CAS, and the list is subject to change.

For more information about journal titles and abbreviations for publications indexed by CAS since 1907 please consult the CAS Source Index (CASSI) search tool

Publication Title | CODEN
ACS Appl. Mater. Interfaces ACS Applied Materials & Interfaces | AAMICK
ACS Biomater. Sci. Eng. ACS Biomaterials Science & Engineering | ABSEBA
ACS Catal. ACS Catalysis | ACCACS
ACS Cent. Sci. ACS Central Science | ACSCII
ACS Chem. Biol. ACS Chemical Biology | ACBCCT
ACS Chem. Neurosci. ACS Chemical Neuroscience | ACNCDM
ACS Comb. Sci. ACS Combinatorial Science | ACSCCC
ACS Infect. Dis. ACS Infectious Diseases | AIDCBC
ACS Macro Lett. ACS Macro Letters | AMLCCD
ACS Med. Chem. Lett. ACS Medicinal Chemistry Letters | AMCLCT
ACS Nano | ANCAC3
ACS Photonics | APCHD5
ACS Sens. ACS Sensors | ASCEFJ
ACS Sustainable Chem. Eng. ACS Sustainable Chemistry & Engineering | ASCECG
ACS Symp. Ser. ACS Symposium Series | ACSMC8
ACS Synth. Biol. ACS Synthetic Biology | ASBCD6
AIChE J. AIChE Journal | AICEAC
APL Mater. APL Materials | AMPADS
ARKIVOC (Gainesville, FL, U. S.) ARKIVOC (Gainesville, FL, United States) | AGFUAR
Acc. Chem. Res. Accounts of Chemical Research | ACHRE4
Acta Biochim. Pol. Acta Biochimica Polonica | ABPLAF
Acta Chim. Slovaca Acta Chimica Slovaca | ACSCHH
Acta Chim. Slov. Acta Chimica Slovenica | ACSLE7
Acta Crystallogr., Sect. A: Found. Adv. Acta Crystallographica, Section A: Foundations and Advances | ACSAD7
Acta Crystallogr., Sect. B: Struct. Sci., Cryst. Eng. Mater. Acta Crystallographica, Section B: Structural Science, Crystal Engineering and Materials | ACSBDA
Acta Crystallogr., Sect. C: Struct. Chem. Acta Crystallographica, Section C: Structural Chemistry | ACSCGG
Acta Crystallogr., Sect. D: Biol. Crystallogr. Acta Crystallographica, Section D: Biological Crystallography | ABCRE6
Acta Crystallogr., Sect. E: Crystallogr. Commun. Acta Crystallographica, Section E: Crystallographic Communications | ACSECI
Acta Crystallogr., Sect. F: Struct. Biol. Commun. Acta Crystallographica, Section F: Structural Biology Communications | ACSFEN
Acta Mater. Acta Materialia | ACMAFD
Acta Pharm. (Zagreb, Croatia) Acta Pharmaceutica (Zagreb, Croatia) | ACPHEE
Acta Pharmacol. Sin. Acta Pharmacologica Sinica | APSCG5
Acta Phys. Pol. A Acta Physica Polonica A | ATPLB6
Acta Physiol. Acta Physiologica | APCHC4
Adsorption | ADSOFO
Adsorpt. Sci. Technol. Adsorption Science & Technology | ASTEEZ
Adv. Drug Delivery Rev. Advanced Drug Delivery Reviews | ADDREP
Adv. Electron. Mater. Advanced Electronic Materials | AEMDBW
Adv. Energy Mater. Advanced Energy Materials | ADEMBC
Adv. Funct. Mater. Advanced Functional Materials | AFMDC6
Adv. Healthcare Mater. Advanced Healthcare Materials | AHMDBJ
Adv. Mater. (Weinheim, Ger.) Advanced Materials (Weinheim, Germany) | ADVMEW
Adv. Opt. Mater. Advanced Optical Materials | AOMDAX
Adv. Synth. Catal. Advanced Synthesis & Catalysis | ASCAF7
Adv. Appl. Ceram. Advances in Applied Ceramics | AACDCN
Adv. Chem. Phys. Advances in Chemical Physics | ADCPAA
Adv. Chromatogr. (Boca Raton, FL, U. S.) Advances in Chromatography (Boca Raton, FL, United States) | ADCYA3
Adv. Colloid Interface Sci. Advances in Colloid and Interface Science | ACISB9
Adv. Electrochem. Sci. Eng. Advances in Electrochemical Science and Engineering | AESEEY
Adv. Enzyme Res. Advances in Enzyme Research | AERDFR
Adv. Inorg. Chem. Advances in Inorganic Chemistry | AICHEP
Adv. Polym. Sci. Advances in Polymer Science | APSIDK
Adv. Polym. Technol. Advances in Polymer Technology | APTYD5
Adv. X-Ray Anal. Advances in X-Ray Analysis | AXRAAA
Aerosol Sci. Technol. Aerosol Science and Technology | ASTYDQ
Afinidad | AFINAE
Aging Cell | ACGECQ
Am. Ceram. Soc. Bull. American Ceramic Society Bulletin | ACSBA7
Am. Chem. Sci. J. American Chemical Science Journal | ACSJCX
Am. J. Clin. Nutr. American Journal of Clinical Nutrition | AJCNAC
Am. J. Hum. Genet. American Journal of Human Genetics | AJHGAG
Am. J. Physiol. American Journal of Physiology | AJPHAP
Am. J. Respir. Cell Mol. Biol. American Journal of Respiratory Cell and Molecular Biology | AJRBEL
Amino Acids | AACIE6
Analyst (Cambridge, U. K.) Analyst (Cambridge, United Kingdom) | ANALAO
Anal. Chim. Acta Analytica Chimica Acta | ACACAM
Anal. Biochem. Analytical Biochemistry | ANBCA2
Anal. Chem. (Washington, DC, U. S.) Analytical Chemistry (Washington, DC, United States) | ANCHAM
Anal. Chem. Lett. Analytical Chemistry Letters | ACLNCA
Anal. Lett. Analytical Letters | ANALBP
Anal. Sci. Analytical Sciences | ANSCEN
Anal. Bioanal. Chem. Analytical and Bioanalytical Chemistry | ABCNBP
Angew. Chem., Int. Ed. Angewandte Chemie, International Edition | ACIEF5
Ann. Pharm. Fr. Annales Pharmaceutiques Francaises | APFRAD
Ann. Chim. (Cachan, Fr.) Annales de Chimie (Cachan, France) | ANCPAC
Ann. Nucl. Energy Annals of Nuclear Energy | ANENDJ
Ann. Nutr. Metab. Annals of Nutrition & Metabolism | ANUMDS
Ann. Phys. (Amsterdam, Neth.) Annals of Physics (Amsterdam, Netherlands) | APNYA6
Ann. Plast. Surg. Annals of Plastic Surgery | APCSD4
Annu. Rev. Biochem. Annual Review of Biochemistry | ARBOAW
Annu. Rev. Biomed. Eng. Annual Review of Biomedical Engineering | ARBEF7
Annu. Rev. Biophys. Annual Review of Biophysics | ARBNCV
Annu. Rev. Cell Dev. Biol. Annual Review of Cell and Developmental Biology | ARDBF8
Annu. Rev. Earth Planet. Sci. Annual Review of Earth and Planetary Sciences | AREPCI
Annu. Rev. Entomol. Annual Review of Entomology | ARENAA
Annu. Rev. Genet. Annual Review of Genetics | ARVGB7
Annu. Rev. Genomics Hum. Genet. Annual Review of Genomics and Human Genetics | ARGHC4
Annu. Rev. Immunol. Annual Review of Immunology | ARIMDU
Annu. Rev. Mater. Res. Annual Review of Materials Research | ARMRCU
Annu. Rev. Med. Annual Review of Medicine | ARMCAH
Annu. Rev. Microbiol. Annual Review of Microbiology | ARMIAZ
Annu. Rev. Neurosci. Annual Review of Neuroscience | ARNSD5
Annu. Rev. Nucl. Part. Sci. Annual Review of Nuclear and Particle Science | ARPSDF
Annu. Rev. Nutr. Annual Review of Nutrition | ARNTD8
Annu. Rev. Pathol.: Mech. Dis. Annual Review of Pathology: Mechanisms of Disease | ARPMCU
Annu. Rev. Pharmacol. Toxicol. Annual Review of Pharmacology and Toxicology | ARPTDI
Annu. Rev. Phys. Chem. Annual Review of Physical Chemistry | ARPLAP
Annu. Rev. Physiol. Annual Review of Physiology | ARPHAD
Annu. Rev. Phytopathol. Annual Review of Phytopathology | APPYAG
Annu. Rev. Plant Biol. Annual Review of Plant Biology | ARPBDW
Annu. Rev. Virol. Annual Review of Virology | ARVNBS
Anti-Cancer Agents Med. Chem. Anti-Cancer Agents in Medicinal Chemistry | AAMCE4
Anti-Cancer Drugs | ANTDEV
Anti-Infect. Agents Anti-Infective Agents | AANGBI
Anti-Inflammatory Anti-Allergy Agents Med. Chem. Anti-Inflammatory & Anti-Allergy Agents in Medicinal Chemistry | AAAMC6
Antibiotics (Basel, Switz.) Antibiotics (Basel, Switzerland) | ABSNC4
Antibiot. Khimioter. Antibiotiki i Khimioterapiya | ANKHEW
Antimicrob. Agents Chemother. Antimicrobial Agents and Chemotherapy | AMACCQ
Antioxidants | ANTIGE
Antioxid. Redox Signaling Antioxidants & Redox Signaling | ARSIF2
Antiviral Res. Antiviral Research | ARSRDR
Appl. Biochem. Biotechnol. Applied Biochemistry and Biotechnology | ABIBDL
Appl. Biochem. Microbiol. Applied Biochemistry and Microbiology | APBMAC
Appl. Catal., A Applied Catalysis, A: General | ACAGE4
Appl. Catal., B Applied Catalysis, B: Environmental | ACBEE3
Appl. Clay Sci. Applied Clay Science | ACLSER
Appl. Geochem. Applied Geochemistry | APPGEY
Appl. Microbiol. Biotechnol. Applied Microbiology and Biotechnology | AMBIDG
Appl. Nanosci. Applied Nanoscience | ANPACY
Appl. Organomet. Chem. Applied Organometallic Chemistry | AOCHEX
Appl. Phys. A: Mater. Sci. Process. Applied Physics A: Materials Science & Processing | APAMFC
Appl. Phys. B: Lasers Opt. Applied Physics B: Lasers and Optics | APBOEM
Appl. Phys. Express Applied Physics Express | APEPC4
Appl. Phys. Lett. Applied Physics Letters | APPLAB
Appl. Phys. Rev. Applied Physics Reviews | APRPG5
Appl. Radiat. Isot. Applied Radiation and Isotopes | ARISEF
Appl. Spectrosc. Applied Spectroscopy | APSPA4
Appl. Surf. Sci. Applied Surface Science | ASUSEE
Appl. Environ. Microbiol. Applied and Environmental Microbiology | AEMIDF
Aquat. Toxicol. Aquatic Toxicology | AQTODG
Archaea | ARCHCI
Arch. Pharm. (Weinheim, Ger.) Archiv der Pharmazie (Weinheim, Germany) | ARPMAS
Arch. Biochem. Biophys. Archives of Biochemistry and Biophysics | ABBIA4
Arch. Environ. Contam. Toxicol. Archives of Environmental Contamination and Toxicology | AECTCV
Arch. Insect Biochem. Physiol. Archives of Insect Biochemistry and Physiology | AIBPEA
Arch. Microbiol. Archives of Microbiology | AMICCW
Arch. Pharmacal Res. Archives of Pharmacal Research | APHRDQ
Arch. Physiol. Biochem. Archives of Physiology and Biochemistry | APBIF5
Arch. Toxicol. Archives of Toxicology | ARTODN
Arch. Virol. Archives of Virology | ARVIDF
Arterioscler., Thromb., Vasc. Biol. Arteriosclerosis, Thrombosis, and Vascular Biology | ATVBFA
Asia-Pac. J. Chem. Eng. Asia-Pacific Journal of Chemical Engineering | AJCEBK
Asian J. Chem. Asian Journal of Chemistry | AJCHEW
Asian J. Org. Chem. Asian Journal of Organic Chemistry | AJOCC7
Assay Drug Dev. Technol. Assay and Drug Development Technologies | ADDTAR
Atherosclerosis (Amsterdam, Neth.) Atherosclerosis (Amsterdam, Netherlands) | ATHSBL
Atmos. Chem. Phys. Atmospheric Chemistry and Physics | ACPTCE
Atmos. Environ. Atmospheric Environment | AENVEQ
At. Energy (N. Y., NY, U. S.) Atomic Energy (New York, NY, United States) | AENYEZ
At. Spectrosc. Atomic Spectroscopy | ASPND7
Aust. J. Chem. Australian Journal of Chemistry | AJCHAS
Auton. Autacoid Pharmacol. Autonomic & Autacoid Pharmacology | AAPUC3
Azerb. Khim. Zh. Azerbaidzhanskii Khimicheskii Zhurnal | AZKZAU
BMB Rep. BMB Reports | BRMEC2
Basic Clin. Pharmacol. Toxicol. Basic & Clinical Pharmacology & Toxicology | BCPTBO
Beilstein J. Nanotechnol. Beilstein Journal of Nanotechnology | BJNEAH
Beilstein J. Org. Chem. Beilstein Journal of Organic Chemistry | BJOCBH
BioChem.: Indian J. BioChemistry: An Indian Journal | BIOCCB
BioChip J. BioChip Journal | BJIODP
BioFactors | BIFAEU
BioInorg. React. Mech. BioInorganic Reaction Mechanisms | BRMIBD
BioMetals | BOMEEH
BioResources | BIORCM
BioTechniques | BTNQDO
Bioact. Carbohydr. Diet. Fibre Bioactive Carbohydrates and Dietary Fibre | BCDFBO
Bioanalysis | BIOAB4
Biocatal. Biotransform. Biocatalysis and Biotransformation | BOBOEQ
Biochem. Genet. Biochemical Genetics | BIGEBA
Biochem. J. Biochemical Journal | BIJOAK
Biochem. Pharmacol. (Amsterdam, Neth.) Biochemical Pharmacology (Amsterdam, Netherlands) | BCPCA6
Biochem. Soc. Trans. Biochemical Society Transactions | BCSTB5
Biochem. Syst. Ecol. Biochemical Systematics and Ecology | BSECBU
Biochem. Biophys. Res. Commun. Biochemical and Biophysical Research Communications | BBRCA9
Biochemistry | BICHAW
Biochemistry (Moscow) | BIORAK
Biochem. Cell Biol. Biochemistry and Cell Biology | BCBIEQ
Biochem. Mol. Biol. Educ. Biochemistry and Molecular Biology Education | BMBECE
Biochim. Biophys. Acta, Bioenerg. Biochimica et Biophysica Acta, Bioenergetics | BBBEB4
Biochim. Biophys. Acta, Biomembr. Biochimica et Biophysica Acta, Biomembranes | BBBMBS
Biochim. Biophys. Acta, Gene Regul. Mech. Biochimica et Biophysica Acta, Gene Regulatory Mechanisms | BBAGC6
Biochim. Biophys. Acta, Gen. Subj. Biochimica et Biophysica Acta, General Subjects | BBGSB3
Biochim. Biophys. Acta, Mol. Basis Dis. Biochimica et Biophysica Acta, Molecular Basis of Disease | BBADEX
Biochim. Biophys. Acta, Mol. Cell Res. Biochimica et Biophysica Acta, Molecular Cell Research | BBAMCO
Biochim. Biophys. Acta, Mol. Cell Biol. Lipids Biochimica et Biophysica Acta, Molecular and Cell Biology of Lipids | BBMLFG
Biochim. Biophys. Acta, Proteins Proteomics Biochimica et Biophysica Acta, Proteins and Proteomics | BBAPBW
Biochim. Biophys. Acta, Rev. Cancer Biochimica et Biophysica Acta, Reviews on Cancer | BBACEU
Biochimie | BICMBE
Bioconjugate Chem. Bioconjugate Chemistry | BCCHES
Bioelectrochemistry | BIOEFK
Biofuels | BIOFGO
Biofuels, Bioprod. Biorefin. Biofuels, Bioproducts & Biorefining | BBBICH
Biog. Amines Biogenic Amines | BIAME7
Bioinformatics | BOINFP
Bioinorg. Chem. Appl. Bioinorganic Chemistry and Applications | BCAIAH
Biol. Pharm. Bull. Biological & Pharmaceutical Bulletin | BPBLEO
Biol. Chem. Biological Chemistry | BICHF3
Biol. Trace Elem. Res. Biological Trace Element Research | BTERDG
Biol. Membr. Biologicheskie Membrany | BIMEE9
Biol. Reprod. Biology of Reproduction | BIREBV
Biomacromol. Mass Spectrom. Biomacromolecular Mass Spectrometry | BMSIB8
Biomacromolecules | BOMAF6
Biomarkers | BIOMFA
Biomarkers Med. Biomarkers in Medicine | BMIEDG
Biomaterials | BIMADU
Biomater. Sci. Biomaterials Science | BSICCH
Biomed. Chromatogr. Biomedical Chromatography | BICHE2
Biomed. Mater. (Bristol, U. K.) Biomedical Materials (Bristol, United Kingdom) | BMBUCS
Biomed. Res. Biomedical Research | BRESD5
Biomed. Khim. Biomeditsinskaya Khimiya | BKIHA8
Biomol. Concepts Biomolecular Concepts | BCIOB8
Biomol. NMR Assignments Biomolecular NMR Assignments | BNAIBR
Biomolecules | BIOMHC
Bioorg. Med. Chem. Bioorganic & Medicinal Chemistry | BMECEP
Bioorg. Med. Chem. Lett. Bioorganic & Medicinal Chemistry Letters | BMCLE8
Bioorg. Chem. Bioorganic Chemistry | BOCMBM
Biopharm. Drug Dispos. Biopharmaceutics & Drug Disposition | BDDID8
Biophys. Chem. Biophysical Chemistry | BICIAZ
Biophys. J. Biophysical Journal | BIOJAU
Biophysics (Engl. Transl.) Biophysics (English Translation) | BIOPAE
Biopolymers | BIPMAA
Bioprocess Biosyst. Eng. Bioprocess and Biosystems Engineering | BBEIBV
Bioresour. Technol. Bioresource Technology | BIRTEB
Biosci. Rep. Bioscience Reports | BRPTDT
Biosci., Biotechnol., Biochem. Bioscience, Biotechnology, and Biochemistry | BBBIEJ
Biosens. Bioelectron. Biosensors & Bioelectronics | BBIOE4
Biotechnol. J. Biotechnology Journal | BJIOAM
Biotechnol. Lett. Biotechnology Letters | BILED3
Biotechnol. Prog. Biotechnology Progress | BIPRET
Biotechnol. Appl. Biochem. Biotechnology and Applied Biochemistry | BABIEC
Biotechnol. Bioeng. Biotechnology and Bioengineering | BIBIAU
Biotechnol. Bioprocess Eng. Biotechnology and Bioprocess Engineering | BBEIAU
Birth Defects Res., Part A Birth Defects Research, Part A: Clinical and Molecular Teratology | BDRPBT
Birth Defects Res., Part B Birth Defects Research, Part B: Developmental and Reproductive Toxicology | BDRPCU
Birth Defects Res., Part C Birth Defects Research, Part C: Embryo Today--Reviews | BDRPDV
Bitamin | BTMNA7
Blood | BLOOAW
Bone Res. Bone Research | BROEBB
Bopuxue Zazhi | BOZAE2
BrJAC--Braz. J. Anal. Chem. BrJAC--Brazilian Journal of Analytical Chemistry | BJACAE
Brain Res. Brain Research | BRREAP
Breast Cancer Manage. Breast Cancer Management | BCMRC4
Br. J. Nutr. British Journal of Nutrition | BJNUAV
Br. J. Pharmacol. British Journal of Pharmacology | BJPCBM
Bull. Environ. Contam. Toxicol. Bulletin of Environmental Contamination and Toxicology | BECTA6
Bull. Mater. Sci. Bulletin of Materials Science | BUMSDW
Bull. Chem. Soc. Jpn. Bulletin of the Chemical Society of Japan | BCSJA8
Bull. Korean Chem. Soc. Bulletin of the Korean Chemical Society | BKCSDE
Bull. Russ. Acad. Sci.: Phys. Bulletin of the Russian Academy of Sciences: Physics | BRSPEX
Bunseki Kagaku | BNSKAK
CALPHAD: Comput. Coupling Phase Diagrams Thermochem. CALPHAD: Computer Coupling of Phase Diagrams and Thermochemistry | CCCTD6
CNS Neurol. Disord.: Drug Targets CNS & Neurological Disorders: Drug Targets | CNDDA3
CNS Oncol. CNS Oncology | CONNCO
CPT: Pharmacometrics Syst. Pharmacol. CPT: Pharmacometrics & Systems Pharmacology | CPSPBR
Cailiao Rechuli Xuebao | CRXAAK
Calcif. Tissue Int. Calcified Tissue International | CTINDZ
Can. J. Chem. Eng. Canadian Journal of Chemical Engineering | CJCEA7
Can. J. Chem. Canadian Journal of Chemistry | CJCHAG
Can. J. Microbiol. Canadian Journal of Microbiology | CJMIAZ
Can. J. Phys. Canadian Journal of Physics | CJPHAD
Can. J. Physiol. Pharmacol. Canadian Journal of Physiology and Pharmacology | CJPPA3
Can. Metall. Q. Canadian Metallurgical Quarterly | CAMQAU
Can. Mineral. Canadian Mineralogist | CAMIA6
Cancer Cell | CCAECI
Cancer Gene Ther. Cancer Gene Therapy | CGTHEG
Cancer Genomics Proteomics Cancer Genomics & Proteomics | CGPAC7
Cancer Lett. (N. Y., NY, U. S.) Cancer Letters (New York, NY, United States) | CALEDQ
Cancer Res. Cancer Research | CNREA8
Cancer Sci. Cancer Science | CSACCM
Carbohydr. Polym. Carbohydrate Polymers | CAPOD8
Carbohydr. Res. Carbohydrate Research | CRBRAT
Carbon | CRBNAH
Carbon Manage. Carbon Management | CMAAC8
Carcinogenesis | CRNGDP
Cardiovasc. Hematol. Agents Med. Chem. Cardiovascular & Hematological Agents in Medicinal Chemistry | CHAAA5
Cardiovasc. Hematol. Disord.: Drug Targets Cardiovascular & Hematological Disorders: Drug Targets | CHDDBU
Cardiovasc. Res. Cardiovascular Research | CVREAU
Catal. Commun. Catalysis Communications | CCAOAC
Catal. Lett. Catalysis Letters | CALEER
Catal. Rev.: Sci. Eng. Catalysis Reviews: Science and Engineering | CRSEC9
Catal. Sci. Technol. Catalysis Science & Technology | CSTAGD
Catal. Today Catalysis Today | CATTEA
Catalysts | CATACJ
Cell (Cambridge, MA, U. S.) Cell (Cambridge, MA, United States) | CELLB5
Cell Biochem. Biophys. Cell Biochemistry and Biophysics | CBBIFV
Cell Biochem. Funct. Cell Biochemistry and Function | CBFUDH
Cell Calcium | CECADV
Cell Cycle | CCEYAS
Cell Host Microbe Cell Host & Microbe | CHMECB
Cell Metab. Cell Metabolism | CMEEB5
Cell Rep. Cell Reports | CREED8
Cell Stem Cell | CSCEC4
Cell. Immunol. Cellular Immunology | CLIMB8
Cell. Microbiol. Cellular Microbiology | CEMIF5
Cell. Physiol. Biochem. Cellular Physiology and Biochemistry | CEPBEW
Cell. Polym. Cellular Polymers | CELPDJ
Cell. Reprogram. Cellular Reprogramming | CREEC7
Cell. Mol. Life Sci. Cellular and Molecular Life Sciences | CMLSFI
Cellul. Chem. Technol. Cellulose Chemistry and Technology | CECTAH
Cem. Concr. Compos. Cement & Concrete Composites | CCOCEG
Cem. Concr. Res. Cement and Concrete Research | CCNRAI
Cent. Nerv. Syst. Agents Med. Chem. Central Nervous System Agents in Medicinal Chemistry | CNSAC3
Ceram. Int. Ceramics International | CINNDH
Ceram.-Silik. Ceramics-Silikaty | CERSEP
Cereal Chem. Cereal Chemistry | CECHAF
Ceska Slov. Farm. Ceska a Slovenska Farmacie | CSLFEK
ChemBioChem | CBCHFX
ChemCatChem | CHEMK3
ChemElectroChem | CHEMRA
ChemMedChem | CHEMGX
ChemNanoMat | CHEMSB
ChemPhysChem | CPCHFT
ChemPlusChem | CHEMM5
ChemSusChem | CHEMIZ
Chem. Sin. Chemica Sinica | CSHIA5
Chem. Pharm. Bull. Chemical & Pharmaceutical Bulletin | CPBTAL
Chem. Biol. Drug Des. Chemical Biology & Drug Design | CBDDAL
Chem. Commun. (Cambridge, U. K.) Chemical Communications (Cambridge, United Kingdom) | CHCOFS
Chem. Eng. Technol. Chemical Engineering & Technology | CETEER
Chem. Eng. Commun. Chemical Engineering Communications | CEGCAK
Chem. Eng. J. (Amsterdam, Neth.) Chemical Engineering Journal (Amsterdam, Netherlands) | CMEJAJ
Chem. Eng. Res. Des. Chemical Engineering Research and Design | CERDEE
Chem. Eng. Sci. Chemical Engineering Research and Design | CESCAC
Chem. Eng. Process. Chemical Engineering and Processing | CENPEU
Chem. Geol. Chemical Geology | CHGEAD
Chem. Pap. Chemical Papers | CHPAEG
Chem. Phys. Chemical Physics | CMPHC2
Chem. Phys. Lett. Chemical Physics Letters | CHPLBC
Chem. Rec. Chemical Record | CRHEAK
Chem. Res. Chin. Univ. Chemical Research in Chinese Universities | CRCUED
Chem. Res. Toxicol. Chemical Research in Toxicology | CRTOEC
Chem. Rev. (Washington, DC, U. S.) Chemical Reviews (Washington, DC, United States) | CHREAY
Chem. Sci. Chemical Science | CSHCCN
Chem. Sci. Trans. Chemical Science Transactions | CSTHCU
Chem. Speciation Bioavailability Chemical Speciation and Bioavailability | CHSBEY
Chem. Biochem. Eng. Q. Chemical and Biochemical Engineering Quarterly | CBEQEZ
Chem. Listy Chemicke Listy | CHLSAC
Chem.-Biol. Interact. Chemico-Biological Interactions | CBINA8
Chem. Ing. Tech. Chemie Ingenieur Technik | CITEAH
Chem. Erde Chemie der Erde | CERDAA
Chemija | CHMJES
Chem. Technol. (Kaunas, Lith.) Chemine Technologija (Kaunas, Lithuania) | CTHEBZ
Chem. Biodiversity Chemistry & Biodiversity | CBHIAM
Chem. Biol. (Oxford, U. K.) Chemistry & Biology (Oxford, United Kingdom) | CBOLE2
Chem. Biol. Interface Chemistry & Biology Interface | CBIHAO
Chem. Ind. (Chichester, U. K.) Chemistry & Industry (Chichester, United Kingdom) | CHINAG
Chem. - Eur. J. Chemistry - A European Journal | CEUJED
Chem. - Asian J. Chemistry - An Asian Journal | CAAJBI
Chem. J. Mold. Chemistry Journal of Moldova | CJMHAW
Chem. Lett. Chemistry Letters | CMLTAG
Chem. Phys. Lipids Chemistry and Physics of Lipids | CPLIA4
Chem. Technol. Fuels Oils Chemistry and Technology of Fuels and Oils | CTFOAK
Chem. Heterocycl. Compd. (N. Y., NY, U. S.) Chemistry of Heterocyclic Compounds (New York, NY, United States) | CHCCAL
Chem. Mater. Chemistry of Materials | CMATEX
Chem. Nat. Compd. Chemistry of Natural Compounds | CHNCA8
ChemistryOpen | CHOPCK
Chemom. Intell. Lab. Syst. Chemometrics and Intelligent Laboratory Systems | CILSEN
Chemosphere | CMSHAF
Chemotherapy (Basel, Switz.) Chemotherapy (Basel, Switzerland) | CHTHBK
Chimia | CHIMAD
Chim. Ind. (Milan, Italy) Chimica e l'Industria (Milan, Italy) | CINMAB
Chin. Chem. Lett. Chinese Chemical Letters | CCLEE7
Chin. J. Chem. Eng. Chinese Journal of Chemical Engineering | CJCEEB
Chin. J. Chem. Phys. Chinese Journal of Chemical Physics | CJCPA6
Chin. J. Chem. Chinese Journal of Chemistry | CJOCEV
Chin. J. Geochem. Chinese Journal of Geochemistry | CJGEEV
Chin. J. Polym. Sci. Chinese Journal of Polymer Science | CJPSEG
Chin. J. Struct. Chem. Chinese Journal of Structural Chemistry | CJSCBE
Chin. Phys. C Chinese Physics C | CPCHCQ
Chirality | CHRLEP
Chromatographia | CHRGB7
Chromatogr. Res. Int. Chromatography Research International | CRIHBZ
Chromosome Res. Chromosome Research | CRRSEE
Circ. Res. Circulation Research | CIRUAL
Clay Miner. Clay Minerals | CLMIAF
Clays Clay Miner. Clays and Clay Minerals | CLCMAB
Clean: Soil, Air, Water | CSAWAC
Clin. Chim. Acta Clinica Chimica Acta | CCATAR
Clin. Chem. (Washington, DC, U. S.) Clinical Chemistry (Washington, DC, United States) | CLCHAU
Clin. Chem. Lab. Med. Clinical Chemistry and Laboratory Medicine | CCLMFW
Clin. Immunol. (Amsterdam, Neth.) Clinical Immunology (Amsterdam, Netherlands) | CLIIFY
Clin. Proteomics Clinical Proteomics | CPLRCX
Clin. Exp. Pharmacol. Physiol. Clinical and Experimental Pharmacology and Physiology | CEXPB9
Clin. Vaccine Immunol. Clinical and Vaccine Immunology | CVILA6
Coatings | COATED
Colloid J. Colloid Journal | CJRSEQ
Colloid Polym. Sci. Colloid and Polymer Science | CPMSB6
Colloids Surf., A Colloids and Surfaces, A: Physicochemical and Engineering Aspects | CPEAEH
Colloids Surf., B Colloids and Surfaces, B: Biointerfaces | CSBBEQ
Color. Technol. Coloration Technology | CTOEAZ
Comb. Chem. High Throughput Screening Combinatorial Chemistry & High Throughput Screening | CCHSFU
Combust. Sci. Technol. Combustion Science and Technology | CBSTB9
Combust. Flame Combustion and Flame | CBFMAO
Comments Inorg. Chem. Comments on Inorganic Chemistry | COICDZ
Commun. Soil Sci. Plant Anal. Communications in Soil Science and Plant Analysis | CSOSA2
Comp. Biochem. Physiol., Part A: Mol. Integr. Physiol. Comparative Biochemistry and Physiology, Part A: Molecular & Integrative Physiology | CBPAB5
Comp. Biochem. Physiol., Part B: Biochem. Mol. Biol. Comparative Biochemistry and Physiology, Part B: Biochemistry & Molecular Biology | CBPBB8
Comp. Biochem. Physiol., Part C: Toxicol. Pharmacol. Comparative Biochemistry and Physiology, Part C: Toxicology & Pharmacology | CBPPFK
Comp. Biochem. Physiol., Part D: Genomics Proteomics Comparative Biochemistry and Physiology, Part D: Genomics & Proteomics | CBPPBG
Comp. Med. Comparative Medicine | COMEFT
Complex Met. Complex Metals | CMOEBL
C. R. Chim. Comptes Rendus Chimie | CRCOCR
C. R. Phys. Comptes Rendus Physique | CRPOBN
Comput. Theor. Chem. Computational & Theoretical Chemistry | CTCOA5
Comput. Biol. Chem. Computational Biology and Chemistry | CBCOCH
Comput. Phys. Commun. Computer Physics Communications | CPHCBZ
Comput. Chem. Eng. Computers & Chemical Engineering | CCENDW
Contrast Media Mol. Imaging Contrast Media & Molecular Imaging | CMMICO
Contrib. Mineral. Petrol. | CMPEAP
Contributions to Mineralogy and Petrology
Coord. Chem. Rev. | CCHRAM
Coordination Chemistry Reviews
Corrosion (Houston, TX, U. S.) | CORRAK
Corrosion (Houston, TX, United States)
Corros. Eng., Sci. Technol. | CESTBU
Corrosion Engineering, Science and Technology
Corros. Rev. | CORVE2
Corrosion Reviews
Corros. Sci. | CRRSAA
Corrosion Science
Crit. Rev. Anal. Chem. | CCACBB
Critical Reviews in Analytical Chemistry
Crit. Rev. Solid State Mater. Sci. | CCRSDA
Critical Reviews in Solid State and Materials Sciences
Croat. Chem. Acta | CCACAA
Croatica Chemica Acta
Cryogenics | CRYOAX
CrystEngComm | CRECF4
Cryst. Growth Des. | CGDEFU
Crystal Growth & Design
Cryst. Res. Technol. | CRTEDF
Crystal Research and Technology
Crystallogr. Rep. | CYSTE3
Crystallography Reports
Crystals | CRYSBC
Cuihua Xuebao | THHPD3
Curr. Alzheimer Res. | CARUBY
Current Alzheimer Research
Curr. Anal. Chem. | CACUBR
Current Analytical Chemistry
Curr. Bioact. Compd. | CBCUBY
Current Bioactive Compounds
Curr. Bioinf. | CBUIBK
Current Bioinformatics
Curr. Biol. | CUBLE2
Current Biology
Curr. Cancer Drug Targets | CCDTB9
Current Cancer Drug Targets
Curr. Catal. | CCUAA2
Current Catalysis
Curr. Chem. Biol. | CCBUB2
Current Chemical Biology
Curr. Comput.-Aided Drug Des. | CCDDAS
Current Computer-Aided Drug Design
Curr. Drug Delivery | CDDUBJ
Current Drug Delivery
Curr. Drug Discovery Technol. | CDDTAF
Current Drug Discovery Technologies
Curr. Drug Metab. | CDMUBU
Current Drug Metabolism
Curr. Drug Targets | CDTUAU
Current Drug Targets
Curr. Enzyme Inhib. | CEIUAG
Current Enzyme Inhibition
Curr. Gene Ther. | CGTUAH
Current Gene Therapy
Curr. Genet. | CUGED5
Current Genetics
Curr. Genomics | CGUEA8
Current Genomics
Curr. Green Chem. | CGCUAY
Current Green Chemistry
Curr. HIV Res. | CHRUBF
Current HIV Research
Curr. Immunol. Rev. | CIRUBM
Current Immunology Reviews
Curr. Inorg. Chem. | CICUBF
Current Inorganic Chemistry
Curr. Med. Chem. | CMCHE7
Current Medicinal Chemistry
Curr. Metabolomics | CMUECI
Current Metabolomics
Curr. Microbiol. | CUMIDD
Current Microbiology
Curr. Microwave Chem. | CMCUB9
Current Microwave Chemistry
Curr. Mol. Med. | CMMUBP
Current Molecular Medicine
Curr. Mol. Pharmacol. | CMPUB6
Current Molecular Pharmacology
Curr. Neuropharmacol. | CNUEAN
Current Neuropharmacology
Curr. Opin. Biotechnol. | CUOBE3
Current Opinion in Biotechnology
Curr. Opin. Cell Biol. | COCBE3
Current Opinion in Cell Biology
Curr. Opin. Chem. Biol. | COCBF4
Current Opinion in Chemical Biology
Curr. Opin. Colloid Interface Sci. | COCSFL
Current Opinion in Colloid & Interface Science
Curr. Opin. Genet. Dev. | COGDET
Current Opinion in Genetics & Development
Curr. Opin. Immunol. | COPIEL
Current Opinion in Immunology
Curr. Opin. Lipidol. | COPLEU
Current Opinion in Lipidology
Curr. Opin. Neurobiol. | COPUEN
Current Opinion in Neurobiology
Curr. Opin. Pharmacol. | COPUBK
Current Opinion in Pharmacology
Curr. Opin. Struct. Biol. | COSBEF
Current Opinion in Structural Biology
Curr. Org. Chem. | CORCFE
Current Organic Chemistry
Curr. Org. Synth. | COSUC2
Current Organic Synthesis
Curr. Organocatal. | COURC3
Current Organocatalysis
Curr. Pharm. Anal. | CPAUBK
Current Pharmaceutical Analysis
Curr. Pharm. Biotechnol. | CPBUBP
Current Pharmaceutical Biotechnology
Curr. Pharm. Des. | CPDEFP
Current Pharmaceutical Design
Curr. Pharmacogenomics Pers. Med. | CPPMC4
Current Pharmacogenomics and Personalized Medicine
Curr. Protein Pept. Sci. | CPPSCM
Current Protein and Peptide Science
Curr. Proteomics | CPURCA
Current Proteomics
Curr. Radiopharm. | CRUAC7
Current Radiopharmaceuticals
Curr. Signal Transduction Ther. | CSTTBV
Current Signal Transduction Therapy
Curr. Stem Cell Res. Ther. | CSCRC9
Current Stem Cell Research & Therapy
Curr. Top. Med. Chem. (Sharjah, United Arab Emirates) | CTMCCL
Current Topics in Medicinal Chemistry (Sharjah, United Arab Emirates)
Curr. Vasc. Pharmacol. | CVPUAY
Current Vascular Pharmacology
Cytokine Growth Factor Rev. | CGFRFB
Cytokine & Growth Factor Reviews
Cytokine+ | CYTIE9
DNA Repair | DRNEAR
DNA Res. | DARSE8
DNA Research
DNA Cell Biol. | DCEBE8
DNA and Cell Biology
Dalton Trans. | DTARAF
Dalton Transactions
Dermatol. Clin. | DRMCDJ
Dermatologic Clinics
Dermatol. Surg. | DESUFE
Dermatologic Surgery
Desalination | DSLNAH
Des. Monomers Polym. | DMPOF3
Designed Monomers and Polymers
Development (Cambridge, U. K.) | DEVPED
Development (Cambridge, United Kingdom)
Dev. Biol. (Amsterdam, Neth.) | DEBIAO
Developmental Biology (Amsterdam, Netherlands)
Dev. Cell | DCEEBE
Developmental Cell
Dev. Neurosci. (Basel, Switz.) | DENED7
Developmental Neuroscience (Basel, Switzerland)
Diabetes | DIAEAZ
Diamond Relat. Mater. | DRMTE3
Diamond and Related Materials
Dianhuaxue | DIANFX
Differentiation (Oxford, U. K.) | DFFNAW
Differentiation (Oxford, United Kingdom)
Diqiu Huaxue | TCHHCB
Dokl. Biochem. Biophys. | DBBOAL
Doklady Biochemistry and Biophysics
Dokl. Chem. | DKCHAY
Doklady Chemistry
Dokl. Earth Sci. | DESOAP
Doklady Earth Sciences
Dokl. Phys. Chem. | DKPCAG
Doklady Physical Chemistry
Dokl. Phys. | DOPHFU
Doklady Physics
Dopov. Nats. Akad. Nauk Ukr. | DNAUFL
Dopovidi Natsional'noi Akademii Nauk Ukraini
Drug Delivery | DDELEB
Drug Dev. Res. | DDREDK
Drug Development Research
Drug Dev. Ind. Pharm. | DDIPD8
Drug Development and Industrial Pharmacy
Drug Metab. Dispos. | DMDSAI
Drug Metabolism & Disposition
Drug Metab. Lett. | DMLRBM
Drug Metabolism Letters
Drug Res. (Stuttgart, Ger.) | DRSGAO
Drug Research (Stuttgart, Germany)
Drug Test. Anal. | DTARBG
Drug Testing and Analysis
Drug Chem. Toxicol. (1977) | DCTODJ
Drug and Chemical Toxicology (1977)
Dyes Pigm. | DYPIDX
Dyes and Pigments
ECS J. Solid State Sci. Technol. | EJSSBG
ECS Journal of Solid State Science and Technology
ECS Trans. | ECSTF8
ECS Transactions
EMBO J. | EMJODG
EMBO Journal
EMBO Mol. Med. | EMMMAM
EMBO Molecular Medicine
EMBO Rep. | ERMEAX
EMBO Reports
EPJ Photovoltaics | EPPHBA
EPL | EPLAC4
Earth Planet. Sci. Lett. | EPSLA2
Earth and Planetary Science Letters
Ecotoxicology | ECOTEL
Ecotoxicol. Environ. Saf. | EESADV
Ecotoxicology and Environmental Safety
Eksp. Klin. Farmakol. | EKFAE9
Eksperimental'naya i Klinicheskaya Farmakologiya
Electroanalysis | ELANEU
Electrocatalysis | ELECCF
Electrochem. Soc. Interface | ELSIE3
Electrochemical Society Interface
Electrochemistry (Tokyo, Jpn.) | EECTFA
Electrochemistry (Tokyo, Japan)
Electrochem. Commun. | ECCMF9
Electrochemistry Communications
Electrochim. Acta | ELCAAV
Electrochimica Acta
Electron. Mater. Lett. | EMLLAE
Electronic Materials Letters
Electrophoresis | ELCTDN
Endocrine | EOCRE5
Endocr., Metab. Immune Disord.: Drug Targets | EMIDA9
Endocrine, Metabolic & Immune Disorders: Drug Targets
Endocrinology | ENDOAO
Energotekhnol. Resursosberezhenie | ERNEB5
Energotekhnologii i Resursosberezhenie
Energy Fuels | ENFUEM
Energy & Fuels
Eng. Life Sci. | ELSNAE
Engineering in Life Sciences
Environ. Chem. | ECNHAA
Environmental Chemistry
Environ. Chem. Lett. | ECLNBJ
Environmental Chemistry Letters
Environ. Eng. Sci. | EESCF5
Environmental Engineering Science
Environ. Geochem. Health | EGHEE3
Environmental Geochemistry and Health
Environ. Pollut. (Oxford, U. K.) | ENPOEK
Environmental Pollution (Oxford, United Kingdom)
Environ. Prog. Sustainable Energy | EPSECH
Environmental Progress & Sustainable Energy
Environ. Res. | ENVRAL
Environmental Research
Environ. Sci. Technol. | ESTHAG
Environmental Science & Technology
Environ. Sci. Technol. Lett. | ESTLCU
Environmental Science & Technology Letters
Environ. Sci.: Nano | ESNNA4
Environmental Science: Nano
Environ. Sci.: Processes Impacts | ESPICZ
Environmental Science: Processes & Impacts
Environ. Technol. Environmental Technology | ENVTEV
Environ. Toxicol. Environmental Toxicology | ETOXFH
Environ. Toxicol. Chem. Environmental Toxicology and Chemistry | ETOCDK
Environ. Toxicol. Pharmacol. | ETOPFR
Environmental Toxicology and Pharmacology
Environ. Mol. Mutagen. | EMMUEG
Environmental and Molecular Mutagenesis
Enzyme Microb. Technol. | EMTED2
Enzyme and Microbial Technology
Epigenomics | EPIGC7
Eukaryotic Cell | ECUEA2
Eur. Cytokine Network | ECYNEJ
European Cytokine Network
Eur. Food Res. Technol. | EFRTFO
European Food Research and Technology
Eur. J. Cell Biol. | EJCBDN
European Journal of Cell Biology
Eur. J. Chem. | EJCUA9
European Journal of Chemistry
Eur. J. Drug Metab. Pharmacokinet. | EJDPD2
European Journal of Drug Metabolism and Pharmacokinetics
Eur. J. Endocrinol. | EJOEEP
European Journal of Endocrinology
Eur. J. Immunol. | EJIMAF
European Journal of Immunology
Eur. J. Inorg. Chem. | EJICFO
European Journal of Inorganic Chemistry
Eur. J. Lipid Sci. Technol. | EJLTFM
European Journal of Lipid Science and Technology
Eur. J. Mass Spectrom. | EJMSCL
European Journal of Mass Spectrometry
Eur. J. Med. Chem. | EJMCA5
European Journal of Medicinal Chemistry
Eur. J. Mineral. | EJMIER
European Journal of Mineralogy
Eur. J. Org. Chem. | EJOCFK
European Journal of Organic Chemistry
Eur. J. Pharm. Sci. | EPSCED
European Journal of Pharmaceutical Sciences
Eur. J. Pharmacol. | EJPHAZ
European Journal of Pharmacology
Eur. Neuropsychopharmacol. | EURNE8
European Neuropsychopharmacology
Eur. Phys. J. A | EPJAFV
European Physical Journal A: Hadrons and Nuclei
Eur. Phys. J. B | EPJBFY
European Physical Journal B: Condensed Matter and Complex
Systems
Eur. Phys. J. C | EPCFFB
European Physical Journal C: Particles and Fields
Eur. Phys. J. D | EPJDF6
European Physical Journal D: Atomic, Molecular, Optical and Plasma Physics
Eur. Phys. J. E: Soft Matter Biol. Phys. | EPJSFH
European Physical Journal E: Soft Matter and Biological Physics
Eur. Polym. J. | EUPJAG
European Polymer Journal
Exp. Mol. Med. | EMMEF3
Experimental & Molecular Medicine
Exp. Anim. | JIDOAA
Experimental Animals
Exp. Biol. Med. (London, U. K.) | EBMMBE
Experimental Biology and Medicine (London, United Kingdom)
Exp. Cell Res. | ECREAL
Experimental Cell Research
Exp. Eye Res. | EXERA6
Experimental Eye Research
Exp. Clin. Endocrinol. Diabetes | ECEDFQ
Experimental and Clinical Endocrinology & Diabetes
Exp. Mol. Pathol. | EXMPA6
Experimental and Molecular Pathology
Expert Opin. Invest. Drugs | EOIDER
Expert Opinion on Investigational Drugs
Expert Opin. Ther. Pat. | EOTPEG
Expert Opinion on Therapeutic Patents
Expert Rev. Anti-Infect. Ther. | ERATCK
Expert Review of Anti-Infective Therapy
Expert Rev. Anticancer Ther. | ERATBJ
Expert Review of Anticancer Therapy
Expert Rev. Cardiovasc. Ther. | ERCTAS
Expert Review of Cardiovascular Therapy
Expert Rev. Clin. Immunol. | ERCIBU
Expert Review of Clinical Immunology
Expert Rev. Clin. Pharmacol. | ERCPAG
Expert Review of Clinical Pharmacology
Expert Rev. Endocrinol. Metab. | EREMBI
Expert Review of Endocrinology & Metabolism
Expert Rev. Gastroenterol. Hepatol. | ERGHBD
Expert Review of Gastroenterology & Hepatology
Expert Rev. Hematol. | ERHXAV
Expert Review of Hematology
Expert Rev. Med. Devices | ERMDDX
Expert Review of Medical Devices
Expert Rev. Mol. Diagn. | ERMDCW
Expert Review of Molecular Diagnostics
Expert Rev. Neurother. | ERNXAR
Expert Review of Neurotherapeutics
Expert Rev. Ophthalmol. | EROXAW
Expert Review of Ophthalmology
Expert Rev. Proteomics | ERPXA3
Expert Review of Proteomics
Expert Rev. Respir. Med. | ERRMBF
Expert Review of Respiratory Medicine
Expert Rev. Vaccines Expert Review of Vaccines | ERVXAX
FASEB J. FASEB Journal | FAJOEC
FEBS J. FEBS Journal | FJEOAC
FEBS Lett. FEBS Letters | FEBLAL
FEBS Open Bio | FOBEB3
Facial Plast. Surg. Facial Plastic Surgery | FPSUEA
Faraday Discuss. Faraday Discussions | FDISE6
Fenxi Huaxue | FHHHDT
Fenzi Cuihua | FECUEN
Ferroelectrics | FEROA8
Ferroelectr., Lett. Sect. Ferroelectrics, Letters Section | FELEDJ
Fibre Chem. Fibre Chemistry | FICYAP
Fire Mater. Fire and Materials | FMATDV
Fish Physiol. Biochem. Fish Physiology and Biochemistry | FPBIEP
Fish. Sci. (Tokyo, Jpn.) | FSCIEH
Fisheries Science (Tokyo, Japan)
Fiz. Met. Metalloved. | FMMTAK
Fizika Metallov i Metallovedenie
Fluid Phase Equilib. | FPEQDT
Fluid Phase Equilibria
Folia Microbiol. (Dordrecht, Neth.) | FOMIAZ
Folia Microbiologica (Dordrecht, Netherlands)
Food Funct. | FFOUAI
Food & Function
Food Addit. Contam., Part A | FACPAA
Food Additives & Contaminants, Part A
Food Addit. Contam., Part B | FACPBB
Food Additives & Contaminants, Part B: Surveillance
Food Chem. | FOCHDJ
Food Chemistry
Food Hydrocolloids | FOHYES
Food Chem. Toxicol. | FCTOD7
Food and Chemical Toxicology
Free Radical Biol. Med. | FRBMEH
Free Radical Biology & Medicine
Free Radical Res. | FRARER
Free Radical Research
Fresenius Environ. Bull. | FENBEL
Fresenius Environmental Bulletin
Fuel | FUELAC
Fuel Cells (Weinheim, Ger.) | FUCEFK
Fuel Cells (Weinheim, Germany)
Fuel Process. Technol. | FPTEDY
Fuel Processing Technology
Fullerenes, Nanotubes, Carbon Nanostruct. | FNCNAR
Fullerenes, Nanotubes, and Carbon Nanostructures
Funct. Integr. Genomics | FIGUBY
Functional & Integrative Genomics
Fundam. Clin. Pharmacol. | FCPHEZ
Fundamental & Clinical Pharmacology
Funtai oyobi Funmatsu Yakin | FOFUA2
Fusion Eng. Des. Fusion Engineering and Design | FEDEEE
Future Cardiol. | FCUAAZ
Future Cardiology
Future Med. Chem. | FMCUA7
Future Medicinal Chemistry
Future Microbiol. | FMUIAR
Future Microbiology
Future Neurol. | FNUEAM
Future Neurology
Future Oncol. | FOUNBN
Future Oncology
Future Virol. | FVUIAM
Future Virology
GSTF J. Chem. Sci. | GJCSAP
GSTF Journal of Chemical Sciences
Gaodeng Xuexiao Huaxue Xuebao | KTHPDM
Gaofenzi Cailiao Kexue Yu Gongcheng | GCKGEI
Gaofenzi Xuebao | GAXUE9
Gaoxiao Huaxue Gongcheng Xuebao | GHGXEG
Gene | GENED6
Gene Expression Patterns | GEPEAD
Gene Ther. Gene Therapy | GETHEC
Gen. Comp. Endocrinol. General and Comparative Endocrinology | GCENA5
Genes | GENEG9
Genes Dev. Genes & Development | GEDEEP
Genes Cells Genes to Cells | GECEFL
Genes, Chromosomes Cancer Genes, Chromosomes & Cancer | GCCAES
Genome Res. | GEREFS
Genome Research
Genomics | GNMCEP
Geochem. J. | GEJOBE
Geochemical Journal
Geochem. Trans. | GETRF9
Geochemical Transactions
Geochem. Int. | GCINAP
Geochemistry International
Geochim. Cosmochim. Acta | GCACAK
Geochimica et Cosmochimica Acta
Glass Phys. Chem. | GPHCEE
Glass Physics and Chemistry
Global Biogeochem. Cycles | GBCYEP
Global Biogeochemical Cycles
Glycobiology | GLYCE3
Glycoconjugate J. | GLJOEW
Glycoconjugate Journal
Gongneng Gaofenzi Xuebao | GGXUEH
Graphene | GRAPCU
Green Chem. | GRCHFJ
Green Chemistry
Green Chem. Lett. Rev. | GCLRAI
Green Chemistry Letters and Reviews
Green Process. Synth. | GPSREC
Green Processing and Synthesis
Groundwater | GRWAAP
Growth Factors | GRFAEC
Guangpuxue Yu Guangpu Fenxi | GYGFED
Guijinshu | GUIJE7
Guisuanyan Xuebao | KSYHA5
Guocheng Gongcheng Xuebao | CJPEB5
Health Phys. | HLTPAO
Health Physics
Heat Transfer Eng. | HTEND2
Heat Transfer Engineering
Hecheng Xiangjiao Gongye | HXGOEA
Helv. Chim. Acta | HCACAV
Helvetica Chimica Acta
Hemoglobin | HEMOD8
Heteroat. Chem. | HETCE8
Heteroatom Chemistry
Heterocycles | HTCYAM
Heterocycl. Commun. | HCOMEX
Heterocyclic Communications
Heterocycl. Lett. | HLEEAI
Heterocyclic Letters
High Energy Chem. | HIECAP
High Energy Chemistry
High Perform. Polym. | HPPOEX
High Performance Polymers
High Temp. | HITEA4
High Temperature
High Temp. Mater. Processes (Berlin, Ger.) | HTMPEF
High Temperature Materials and Processes (Berlin, Germany)
Histochem. Cell Biol. | HCBIFP
Histochemistry and Cell Biology
Holzforschung | HOLZAZ
Horm. Mol. Biol. Clin. Invest. | HMBCA4
Hormone Molecular Biology and Clinical Investigation
Horm. Res. Paediatr. | HRPOA9
Hormone Research in Paediatrics
Horm. Metab. Res. | HMMRA2
Hormone and Metabolic Research
Huadong Ligong Daxue Xuebao, Ziran Kexueban | HLIXEV
Huagong Xuebao (Chin. Ed.) | HUKHAI
Huagong Xuebao (Chinese Edition)
Huanjing Huaxue | HUHUDB
Huanjing Kexue Xuebao | HKXUDL
Huaxue | HUHSA2
Huaxue Fanying Gongcheng Yu Gongyi | HFGGEU
Huaxue Shiji | HUSHDR
Huaxue Tongbao | HHTPAU
Huaxue Xuebao | HHHPA4
Hum. Gene Ther. Human Gene Therapy | HGTHE3
Hum. Gene Ther.: Clin. Dev. | HGTCAI
Human Gene Therapy: Clinical Development
Hum. Gene Ther: Methods | HGTPAN
Human Gene Therapy: Methods
Hum. Mol. Genet. | HMGEE5
Human Molecular Genetics
Hum. Ecol. Risk Assess. | HERAFR
Human and Ecological Risk Assessment
Hwahak Konghak | HHKHAT
Hydrometallurgy | HYDRDA
Hyperfine Interact. | HYINDN
Hyperfine Interactions
Hypertension | HPRTDN
IEEE J. Quantum Electron. | IEJQA7
IEEE Journal of Quantum Electronics
IEEE J. Sel. Top. Quantum Electron. | IJSQEN
IEEE Journal of Selected Topics in Quantum Electronics
IEEE Trans. Nanotechnol. | ITNECU
IEEE Transactions on Nanotechnology
ILAR J. | IJLOAC
ILAR Journal
ISIJ Int. | IINTEY
ISIJ International
IUBMB Life | IULIF8
IUCrJ | IUCRAJ
Imaging Med. | IMMECA
Imaging in Medicine
Immunity | IUNIEH
Immunobiology | IMMND4
Immunology | IMMUAM
Immunol. Lett. | IMLED6
Immunology Letters
Immunol., Endocr. Metab. Agents Med. Chem. | IEMACA
Immunology, Endocrine & Metabolic Agents in Medicinal Chemistry
Immunotherapy | IMMUCO
Indian Chem. Eng. | ICENFW
Indian Chemical Engineer
Indian J. Biochem. Biophys. | IJBBBQ
Indian Journal of Biochemistry & Biophysics
Indian J. Chem., Sect. A: Inorg., Bio-inorg., Phys., Theor. Anal. Chem. | ICACEC
Indian Journal of Chemistry, Section A: Inorganic, Bio-inorganic, Physical, Theoretical & Analytical Chemistry
Indian J. Chem., Sect. B: Org. Chem. Incl. Med. Chem. | IJSBDB
Indian Journal of Chemistry, Section B: Organic Chemistry Including Medicinal Chemistry
Indian J. Fibre Text. Res. | IJFRET
Indian Journal of Fibre & Textile Research
Indian J. Heterocycl. Chem. | IJCHEI
Indian Journal of Heterocyclic Chemistry
Indian J. Phys. | IJPNCV
Indian Journal of Physics
Ind. Eng. Chem. Res. | IECRED
Industrial & Engineering Chemistry Research
Infect. Immun. | INFIBR
Infection and Immunity
Infect. Disord.: Drug Targets | IDDTAD
Infectious Disorders: Drug Targets
Inflammation Allergy: Drug Targets | IADTAQ
Inflammation & Allergy: Drug Targets
Inflammation Res. | INREFB
Inflammation Research
Inhalation Toxicol. | INHTE5
Inhalation Toxicology
Innate Immun. | IINMCB
Innate Immunity
Inorg. Chem. | INOCAJ
Inorganic Chemistry
Inorg. Chem. Commun. | ICCOFP
Inorganic Chemistry Communications
Inorg. Chem. Front. | ICFNAW
Inorganic Chemistry Frontiers
Inorg. Mater. | INOMAF
Inorganic Materials
Inorg. Chim. Acta | ICHAA3
Inorganica Chimica Acta
Insect Biochem. Mol. Biol. | IBMBES
Insect Biochemistry and Molecular Biology
Insect Mol. Biol. | IMBIE3
Insect Molecular Biology
Instrum. Sci. Technol. | ISCTEF
Instrumentation Science & Technology
Intermetallics | IERME5
Int. Immunol. | INIMEN
International Immunology
Int. Immunopharmacol. | IINMBA
International Immunopharmacology
Int. J. Vitam. Nutr. Res. | IJVNAP
International Journal for Vitamin and Nutrition Research
Int. J. Adhes. Adhes. | IJAADK
International Journal of Adhesion and Adhesives
Int. J. Antimicrob. Agents | IAAGEA
International Journal of Antimicrobial Agents
Int. J. Appl. Ceram. Technol. | IJACCP
International Journal of Applied Ceramic Technology
Int. J. Biochem. Cell Biol. | IJBBFU
International Journal of Biochemistry & Cell Biology
Int. J. Biol. Macromol. | IJBMDR
International Journal of Biological Macromolecules
Int. J. Biomed. Nanosci. Nanotechnol. | IJBNFW
International Journal of Biomedical Nanoscience and
Nanotechnology
Int. J. Cancer | IJCNAW
International Journal of Cancer
Int. J. Chem. Eng. Appl. | IJCEJE
International Journal of Chemical Engineering and
Applications
Int. J. Chem. Kinet. | IJCKBO
International Journal of Chemical Kinetics
Int. J. Coal Geol. | IJCGDE
International Journal of Coal Geology
Int. J. Coal Prep. Util. | IJCPGA
International Journal of Coal Preparation and Utilization
Int. J. Electrochem. Sci. | IJESIV
International Journal of Electrochemical Science
Int. J. Electrochem. | IJENJH
International Journal of Electrochemistry
Int. J. Environ. Pollut. | IJVLEN
International Journal of Environment and Pollution
Int. J. Environ. Anal. Chem. | IJEAA3
International Journal of Environmental Analytical Chemistry
Int. J. Food Sci. Technol. | IJFTEZ
International Journal of Food Science and Technology
Int. J. Genomics | IJGNFN
International Journal of Genomics
Int. J. Hematol. Oncol. | IJHOCS
International Journal of Hematologic Oncology
Int. J. Hydrogen Energy | IJHEDX
International Journal of Hydrogen Energy
Int. J. Immunogenet. | IJINCU
International Journal of Immunogenetics
Int. J. Mass Spectrom. | IMSPF8
International Journal of Mass Spectrometry
Int. J. Mater. Res. | IJMRFV
International Journal of Materials Research
Int. J. Miner. Process. | IJMPBL
International Journal of Mineral Processing
Int. J. Mod. Chem. | IJMCHM
International Journal of Modern Chemistry
Int. J. Mod. Org. Chem. | IJMOAH
International Journal of Modern Organic Chemistry
Int. J. Multiphase Flow | IJMFBP
International Journal of Multiphase Flow
Int. J. Nanosci. | IJNNAJ
International Journal of Nanoscience
Int. J. Nonferrous Metall. | IJNMJP
International Journal of Nonferrous Metallurgy
Int. J. Org. Chem. | IJOCCR
International Journal of Organic Chemistry
Int. J. PIXE | IJPXET
International Journal of PIXE
Int. J. Pept. Res. Ther. | IJPRFC
International Journal of Peptide Research and Therapeutics
Int. J. Pharm. (Amsterdam, Neth.) | IJPHDE
International Journal of Pharmaceutics (Amsterdam, Netherlands)
Int. J. Polym. Anal. Charact. | IPACEZ
International Journal of Polymer Analysis and Characterization
Int. J. Polym. Mater. Polym. Biomater. | IJPMHX
International Journal of Polymeric Materials and Polymeric Biomaterials
Int. J. Quantum Chem. | IJQCB2
International Journal of Quantum Chemistry
Int. J. Radiat. Biol. | IJRBE7
International Journal of Radiation Biology
Int. J. Refract. Met. Hard Mater. | IRMME3
International Journal of Refractory Metals & Hard Materials
Int. J. Thermophys. | IJTHDY
International Journal of Thermophysics
Int. Mater. Rev. | INMREO
International Materials Reviews
Int. Polym. Process. | IPPREJ
International Polymer Processing
Int. Res. J. Pure Appl. Chem. | IRJPFW
International Research Journal of Pure and Applied Chemistry
Int. Rev. Phys. Chem. | IRPCDL
International Reviews in Physical Chemistry
Ionics | IONIFA
Ironmaking Steelmaking | IMKSB7
Ironmaking & Steelmaking
Isot. Environ. Health Stud. | IEHSF8
Isotopes in Environmental and Health Studies
Isr. J. Chem. | ISJCAT
Israel Journal of Chemistry
Izv. Nats. Akad. Nauk Resp. Kaz., Ser. Khim. Tekhnol. | INANGM
Izvestiya Natsional'noi Akademii Nauk Respubliki Kazakhstan, Seriya Khimii i Tekhnologii
Izv. Vyssh. Uchebn. Zaved., Khim. Khim. Tekhnol. | IVUKAR
Izvestiya Vysshikh Uchebnykh Zavedenii, Khimiya I Khimicheskaya Tekhnologiya
JAMA, J. Am. Med. Assoc. | JAMAAP
JAMA, the Journal of the American Medical Association
JBIC, J. Biol. Inorg. Chem. | JJBCFA
JBIC, Journal of Biological Inorganic Chemistry
JETP Lett. | JTPLA2
JETP Letters
Jpn. J. Appl. Phys. | JJAPB6
Japanese Journal of Applied Physics
Jinshu Xuebao | CHSPA4
Jisuanji Yu Yingyong Huaxue | JYYHE6
J. AOAC Int. | JAINEE
Journal of AOAC International
J. Adhes. | JADNAJ
Journal of Adhesion
J. Adhes. Sci. Technol. | JATEE8
Journal of Adhesion Science and Technology
J. Adv. Ceram. | JACOCJ
Journal of Advanced Ceramics
J. Adv. Dielectr. | JADOBN
Journal of Advanced Dielectrics
J. Aerosol Sci. | JALSB7
Journal of Aerosol Science
J. Agric. Food Chem. | JAFCAU
Journal of Agricultural and Food Chemistry
J. Alloys Compd. | JALCEU
Journal of Alloys and Compounds
J. Anal. At. Spectrom. | JASPE2
Journal of Analytical Atomic Spectrometry
J. Anal. Chem. | JACTE2
Journal of Analytical Chemistry
J. Anal. Methods Chem. | JAMCCX
Journal of Analytical Methods in Chemistry
J. Anal. Toxicol. | JATOD3
Journal of Analytical Toxicology
J. Anal. Appl. Pyrolysis | JAAPDD
Journal of Analytical and Applied Pyrolysis
J. Anim. Sci. (Champaign, IL, U. S.) | JANSAG
Journal of Animal Science (Champaign, IL, United States)
J. Antibiot. | JANTAJ
Journal of Antibiotics
J. Antimicrob. Chemother. | JACHDX
Journal of Antimicrobial Chemotherapy
J. Appl. Anim. Welfare Sci. | JAAWAV
Journal of Applied Animal Welfare Science
J. Appl. Crystallogr. | JACGAR
Journal of Applied Crystallography
J. Appl. Electrochem. | JAELBJ
Journal of Applied Electrochemistry
J. Appl. Phys. (Melville, NY, U. S.) | JAPIAU
Journal of Applied Physics (Melville, NY, United States)
J. Appl. Polym. Sci. | JAPNAB
Journal of Applied Polymer Science
J. Appl. Solution Chem. Model. | JASCCT
Journal of Applied Solution Chemistry and Modeling
J. Appl. Spectrosc. | JASYAP
Journal of Applied Spectroscopy
J. Appl. Toxicol. | JJATDK
Journal of Applied Toxicology
J. Atmos. Chem. | JATCE2
Journal of Atmospheric Chemistry
J. Bacteriol. | JOBAAY
Journal of Bacteriology
J. Biobased Mater. Bioenergy | JBMBAZ
Journal of Biobased Materials and Bioenergy
J. Biochem. Mol. Toxicol. | JBMTFQ
Journal of Biochemical and Molecular Toxicology
J. Biochem. | JOBIAO
Journal of Biochemistry
J. Bioenerg. Biomembr. | JBBID4
Journal of Bioenergetics and Biomembranes
J. Biol. Chem. | JBCHA3
Journal of Biological Chemistry
J. Biomater. Sci., Polym. Ed. | JBSEEA
Journal of Biomaterials Science, Polymer Edition
J. Biomed. Mater. Res., Part A | JBMRCH
Journal of Biomedical Materials Research, Part A
J. Biomed. Mater. Res., Part B | JBMRGL
Journal of Biomedical Materials Research, Part B: Applied Biomaterials
J. Biomed. Nanotechnol. | JBNOAB
Journal of Biomedical Nanotechnology
J. Biomol. NMR | JBNME9
Journal of Biomolecular NMR
J. Biomol. Struct. Dyn. | JBSDD6
Journal of Biomolecular Structure and Dynamics
J. Bionanosci. | JBOIE2
Journal of Bionanoscience
J. Biorem. Biodegrad. | JBBOFO
Journal of Bioremediation & Biodegradation
J. Biosci. Bioeng. | JBBIF6
Journal of Bioscience and Bioengineering
J. Biotechnol. | JBITD4
Journal of Biotechnology
J. CO2 Util. | JCUOAJ
Journal of CO2 Utilization
J. Carbohydr. Chem. | JCACDM
Journal of Carbohydrate Chemistry
J. Cardiovasc. Pharmacol. | JCPCDT
Journal of Cardiovascular Pharmacology
J. Catal. | JCTLA5
Journal of Catalysis
J. Catal. | JCOACH
Journal of Catalysts
J. Cell Biol. | JCLBA3
Journal of Cell Biology
J. Cell Sci. | JNCSAI
Journal of Cell Science
J. Cell. Biochem. | JCEBD5
Journal of Cellular Biochemistry
J. Cell. Physiol. | JCLLAX
Journal of Cellular Physiology
J. Ceram. | JCOECT
Journal of Ceramics
J. Chem. Eng. Data | JCEAAX
Journal of Chemical & Engineering Data
J. Chem. Crystallogr. | JCCYEV
Journal of Chemical Crystallography
J. Chem. Ecol. | JCECD8
Journal of Chemical Ecology
J. Chem. Educ. | JCEDA8
Journal of Chemical Education
J. Chem. Eng. Jpn. | JCEJAQ
Journal of Chemical Engineering of Japan
J. Chem. Inf. Model. | JCISD8
Journal of Chemical Information and Modeling
J. Chem. Phys. | JCPSA6
Journal of Chemical Physics
J. Chem. Res. | JCROA4
Journal of Chemical Research
J. Chem. Sci. (Berlin, Ger.) | JCSBB5
Journal of Chemical Sciences (Berlin, Germany)
J. Chem. Technol. Biotechnol. | JCTBED
Journal of Chemical Technology and Biotechnology
J. Chem. Theory Comput. | JCTCCE
Journal of Chemical Theory and Computation
J. Chem. Thermodyn. | JCTDAF
Journal of Chemical Thermodynamics
J. Chemom. | JOCHEU
Journal of Chemometrics
J. Chromatogr. Sci. | JCHSBZ
Journal of Chromatographic Science
J. Chromatogr. A | JCRAEY
Journal of Chromatography A
J. Chromatogr. B: Anal. Technol. Biomed. Life Sci. | JCBAAI
Journal of Chromatography B: Analytical Technologies in the Biomedical and Life Sciences
J. Chromatogr. Sep. Tech. | JCSTHV
Journal of Chromatography and Separation Techniques
J. Clin. Endocrinol. Metab. | JCEMAZ
Journal of Clinical Endocrinology and Metabolism
J. Cluster Sci. | JCSCEB
Journal of Cluster Science
J. Coat. Technol. Res. | JCTRCP
Journal of Coatings Technology and Research
J. Colloid Interface Sci. | JCISA5
Journal of Colloid and Interface Science
J. Comput. Biol. | JCOBEM
Journal of Computational Biology
J. Comput. Chem. | JCCHDD
Journal of Computational Chemistry
J. Comput. Methods Mol. Des. | JCMMDA
Journal of Computational Methods in Molecular Design
J. Comput. Theor. Nanosci. | JCTNAB
Journal of Computational and Theoretical Nanoscience
J. Comput. Chem., Jpn. | JCCJAG
Journal of Computer Chemistry, Japan
J. Comput.-Aided Mol. Des. | JCADEQ
Journal of Computer-Aided Molecular Design
J. Contam. Hydrol. | JCOHE6
Journal of Contaminant Hydrology
J. Controlled Release | JCREEC
Journal of Controlled Release
J. Coord. Chem. | JCCMBQ
Journal of Coordination Chemistry
J. Cryst. Growth | JCRGAE
Journal of Crystal Growth
J. Dairy Res. | JDRSAN
Journal of Dairy Research
J. Dairy Sci. | JDSCAE
Journal of Dairy Science
J. Dispersion Sci. Technol. | JDTEDS
Journal of Dispersion Science and Technology
J. Drug Targeting | JDTAEH
Journal of Drug Targeting
J. Electroanal. Chem. | JECHES
Journal of Electroanalytical Chemistry
J. Electrochem. Sci. Technol. | JESTIC
Journal of Electrochemical Science and Technology
J. Electron Spectrosc. Relat. Phenom. | JESRAW
Journal of Electron Spectroscopy and Related Phenomena
J. Electron. Mater. | JECMA5
Journal of Electronic Materials
J. Endocrinol. | JOENAK
Journal of Endocrinology
J. Energ. Mater. | JOEMDK
Journal of Energetic Materials
J. Environ. Chem. Eng. | JECEBG
Journal of Environmental Chemical Engineering
J. Environ. Eng. (Reston, VA, U.S.) | JOEEDU
Journal of Environmental Engineering (Reston, VA, United States)
J. Environ. Qual. | JEVQAA
Journal of Environmental Quality
J. Environ. Radioact. | JERAEE
Journal of Environmental Radioactivity
J. Environ. Sci. Eng. (Nagpur, India) | JESEAR
Journal of Environmental Science & Engineering (Nagpur, India)
J. Environ. Sci. Health, Part A: Toxic/Hazard. Subst. Environ. Eng. | JATEF9
Journal of Environmental Science and Health, Part A: Toxic/Hazardous Substances & Environmental Engineering
J. Environ. Sci. Health, Part B | JPFCD2
Journal of Environmental Science and Health, Part B: Pesticides, Food Contaminants, and Agricultural Wastes
J. Enzyme Inhib. Med. Chem. | JEIMAZ
Journal of Enzyme Inhibition and Medicinal Chemistry
J. Exp. Bot. | JEBOA6
Journal of Experimental Botany
J. Exp. Med. | JEMEAV
Journal of Experimental Medicine
J. Exp. Nanosci. | JENOBX
Journal of Experimental Nanoscience
J. Exp. Theor. Phys. | JTPHES
Journal of Experimental and Theoretical Physics
J. Fluorine Chem. | JFLCAR
Journal of Fluorine Chemistry
J. Food Sci. | JFDSAZ
Journal of Food Science
J. Fusion Energy | JFENDS
Journal of Fusion Energy
J. Gen. Virol. | JGVIAY
Journal of General Virology
J. Gen. Appl. Microbiol. | JGAMA9
Journal of General and Applied Microbiology
J. Geochem. Explor. | JGCEAT
Journal of Geochemical Exploration
J. Hazard. Mater. | JHMAD9
Journal of Hazardous Materials
J. Heterocycl. Chem. | JHTCAD
Journal of Heterocyclic Chemistry
J. Histochem. Cytochem. | JHCYAS
Journal of Histochemistry and Cytochemistry
J. Hypertens. | JOHYD3
Journal of Hypertension
J. Imaging Sci. Technol. | JIMTE6
Journal of Imaging Science and Technology
J. Immunoassay Immunochem. | JIIOAZ
Journal of Immunoassay and Immunochemistry
J. Immunol. Methods | JIMMBG
Journal of Immunological Methods
J. Immunol. | JOIMA3
Journal of Immunology
J. Inclusion Phenom. Macrocyclic Chem. | JIPCF5
Journal of Inclusion Phenomena and Macrocyclic Chemistry
J. Ind. Microbiol. Biotechnol. | JIMBFL
Journal of Industrial Microbiology & Biotechnology
J. Ind. Eng. Chem. (Amsterdam, Neth.) | JIECFI
Journal of Industrial and Engineering Chemistry (Amsterdam, Netherlands)
J. Inorg. Biochem. | JIBIDJ
Journal of Inorganic Biochemistry
J. Inorg. Organomet. Polym. Mater. | JIOPAY
Journal of Inorganic and Organometallic Polymers and Materials
J. Insect Physiol. | JIPHAF
Journal of Insect Physiology
J. Interferon Cytokine Res. | JICRFJ
Journal of Interferon & Cytokine Research
J. Labelled Compd. Radiopharm. | JLCRD4
Journal of Labelled Compounds and Radiopharmaceuticals
J. Laser Micro/Nanoeng. | JLMOA8
Journal of Laser Micro/Nanoengineering
J. Leukocyte Biol. | JLBIE7
Journal of Leukocyte Biology
J. Lipid Res. | JLPRAW
Journal of Lipid Research
J. Lipid Sci. Technol. | JLSTAJ
Journal of Lipid Science and Technology
J. Liq. Chromatogr. Relat. Technol. | JLCTFC
Journal of Liquid Chromatography & Related Technologies
J. Low Temp. Phys. | JLTPAC
Journal of Low Temperature Physics
J. Lumin. | JLUMA8
Journal of Luminescence
J. Macromol. Sci., Part A: Pure Appl. Chem. | JSPCE6
Journal of Macromolecular Science, Part A: Pure and Applied Chemistry
J. Macromol. Sci., Part B: Phys. | JMAPBR
Journal of Macromolecular Science, Part B: Physics
J. Magnesium Alloys | JMAOBO
Journal of Magnesium and Alloys
J. Magn. Reson. | JMARF3
Journal of Magnetic Resonance
J. Magn. Magn. Mater. | JMMMDC
Journal of Magnetism and Magnetic Materials
J. Mass Spectrom. | JMSPFJ
Journal of Mass Spectrometry
J. Mater. (N. Y., NY, U. S.) | JMNYBH
Journal of Materials (New York, NY, United States)
J. Mater. Chem. A | JMCAET
Journal of Materials Chemistry A: Materials for Energy and Sustainability
J. Mater. Chem. B | JMCBDV
Journal of Materials Chemistry B: Materials for Biology and Medicine
J. Mater. Chem. C | JMCCCX
Journal of Materials Chemistry C: Materials for Optical and Electronic Devices
J. Mater. Eng. Perform. | JMEPEG
Journal of Materials Engineering and Performance
J. Mater. Res. | JMREEE
Journal of Materials Research
J. Mater. Sci. | JMTSAS
Journal of Materials Science
J. Mater. Sci.: Mater. Electron. | JSMEEV
Journal of Materials Science: Materials in Electronics
J. Mater. Sci.: Mater. Med. | JSMMEL
Journal of Materials Science: Materials in Medicine
J. Math. Chem. | JMCHEG
Journal of Mathematical Chemistry
J. Med. Chem. | JMCMAR
Journal of Medicinal Chemistry
J. Membr. Biol. | JMBBBO
Journal of Membrane Biology
J. Membr. Sci. | JMESDO
Journal of Membrane Science
J. Membr. Sep. Technol. | JMSTGW
Journal of Membrane and Separation Technology
J. Microencapsulation | JOMIEF
Journal of Microencapsulation
J. Mol. Biol. | JMOBAK
Journal of Molecular Biology
J. Mol. Catal. A: Chem. | JMCCF2
Journal of Molecular Catalysis A: Chemical
J. Mol. Catal. B: Enzym. | JMCEF8
Journal of Molecular Catalysis B: Enzymatic
J. Mol. Endocrinol. | JMLEEI
Journal of Molecular Endocrinology
J. Mol. Evol. | JMEVAU
Journal of Molecular Evolution
J. Mol. Graphics Modell. | JMGMFI
Journal of Molecular Graphics & Modelling
J. Mol. Liq. | JMLIDT
Journal of Molecular Liquids
J. Mol. Microbiol. Biotechnol. | JMMBFF
Journal of Molecular Microbiology and Biotechnology
J. Mol. Neurosci. | JMNEES
Journal of Molecular Neuroscience
J. Mol. Recognit. | JMORE4
Journal of Molecular Recognition
J. Mol. Spectrosc. | JMOSA3
Journal of Molecular Spectroscopy
J. Mol. Struct. | JMOSB4
Journal of Molecular Structure
J. Mol. Cell. Cardiol. | JMCDAY
Journal of Molecular and Cellular Cardiology
J. Nanoeng. Nanomanuf. | JNNOFW
Journal of Nanoengineering and Nanomanufacturing
J. Nanopart. | JNOAGU
Journal of Nanoparticles
J. Nanosci. Nanotechnol. | JNNOAR
Journal of Nanoscience and Nanotechnology
J. Nat. Prod. | JNPRDF
Journal of Natural Products
J. Near Infrared Spectrosc. | JNISEI
Journal of Near Infrared Spectroscopy
J. Neurochem. | JONRA9
Journal of Neurochemistry
J. Neuroendocrinol. | JOUNE2
Journal of Neuroendocrinology
J. Neuroimmunol. | JNRIDW
Journal of Neuroimmunology
J. Neurosci. | JNRSDS
Journal of Neuroscience
J. Neurosci. Res. | JNREDK
Journal of Neuroscience Research
J. Non-Cryst. Solids | JNCSBJ
Journal of Non-Crystalline Solids
J. Non-Newtonian Fluid Mech. | JNFMDI
Journal of Non-Newtonian Fluid Mechanics
J. Nucl. Mater. | JNUMAM
Journal of Nuclear Materials
J. Nucl. Sci. Technol. (Abingdon, U. K.) | JNSTAX
Journal of Nuclear Science and Technology (Abingdon, United Kingdom)
J. Nucleic Acids | JNAOAU
Journal of Nucleic Acids
J. Nutr. | JONUAI
Journal of Nutrition
J. Nutr. Biochem. | JNBIEL
Journal of Nutritional Biochemistry
J. Nutr. Sci. Vitaminol. | JNSVA5
Journal of Nutritional Science and Vitaminology
J. Ocul. Pharmacol. Ther. | JOPTFU
Journal of Ocular Pharmacology and Therapeutics
J. Oleo Sci. | JOSOAP
Journal of Oleo Science
J. Org. Chem. | JOCEAH
Journal of Organic Chemistry
J. Organomet. Chem. | JORCAI
Journal of Organometallic Chemistry
J. Pept. Sci. | JPSIEI
Journal of Peptide Science
J. Pet. Sci. Eng. | JPSEE6
Journal of Petroleum Science & Engineering
J. Petrol. | JPTGAD
Journal of Petrology
J. Pharm. Sci. | JPMSAE
Journal of Pharmaceutical Sciences
J. Pharm. Biomed. Anal. | JPBADA
Journal of Pharmaceutical and Biomedical Analysis
J. Pharmacol. Toxicol. Methods | JPTMEZ
Journal of Pharmacological and Toxicological Methods
J. Pharmacol. Exp. Ther. | JPETAB
Journal of Pharmacology and Experimental Therapeutics
J. Pharm. Chem. | JPCOCM
Journal of Pharmacy and Chemistry
J. Pharm. Pharmacol. | JPPMAB
Journal of Pharmacy and Pharmacology
J. Phase Equilib. Diffus. | JPEDAV
Journal of Phase Equilibria and Diffusion
J. Photochem. Photobiol., A | JPPCEJ
Journal of Photochemistry and Photobiology, A: Chemistry
J. Photochem. Photobiol., B | JPPBEG
Journal of Photochemistry and Photobiology, B: Biology
J. Photochem. Photobiol., C | JPPCAF
Journal of Photochemistry and Photobiology, C: Photochemistry Reviews
J. Photopolym. Sci. Technol. | JSTEEW
Journal of Photopolymer Science and Technology
J. Phys. Chem. A | JPCAFH
Journal of Physical Chemistry A
J. Phys. Chem. B | JPCBFK
Journal of Physical Chemistry B
J. Phys. Chem. C | JPCCCK
Journal of Physical Chemistry C
J. Phys. Chem. Lett. | JPCLCD
Journal of Physical Chemistry Letters
J. Phys. Org. Chem. | JPOCEE
Journal of Physical Organic Chemistry
J. Phys. Chem. Ref. Data | JPCRBU
Journal of Physical and Chemical Reference Data
J. Phys. B: At., Mol. Opt. Phys. | JPAPEH
Journal of Physics B: Atomic, Molecular and Optical Physics
J. Phys. D: Appl. Phys. | JPAPBE
Journal of Physics D: Applied Physics
J. Phys. G: Nucl. Part. Phys. | JPGPED
Journal of Physics G: Nuclear and Particle Physics
J. Phys. Chem. Solids | JPCSAW
Journal of Physics and Chemistry of Solids
J. Phys.: Condens. Matter | JCOMEL
Journal of Physics: Condensed Matter
J. Physiol. (Oxford, U. K.) | JPHYA7
Journal of Physiology (Oxford, United Kingdom)
J. Pineal Res. | JPRSE9
Journal of Pineal Research
J. Planar Chromatogr.--Mod. TLC | JPCTE5
Journal of Planar Chromatography--Modern TLC
J. Plant Growth Regul. | JPGRDI
Journal of Plant Growth Regulation
J. Plant Nutr. | JPNUDS
Journal of Plant Nutrition
J. Plant Nutr. Soil Sci. | JNSSFZ
Journal of Plant Nutrition and Soil Science
J. Plant Physiol. | JPPHEY
Journal of Plant Physiology
J. Polym. Mater. | JOPME8
Journal of Polymer Materials
J. Polym. Res. | JPOREP
Journal of Polymer Research
J. Polym. Sci., Part A: Polym. Chem. | JPACEC
Journal of Polymer Science, Part A: Polymer Chemistry
J. Polym. Sci., Part B: Polym. Phys. | JPBPEM
Journal of Polymer Science, Part B: Polymer Physics
J. Polym. Environ. | JPENFW
Journal of Polymers and the Environment
J. Porphyrins Phthalocyanines | JPPHFZ
Journal of Porphyrins and Phthalocyanines
J. Power Sources | JPSODZ
Journal of Power Sources
J. Process Control | JPCOEO
Journal of Process Control
J. Proteome Res. | JPROBS
Journal of Proteome Research
J. Proteomics | JPORFQ
Journal of Proteomics
J. Quant. Spectrosc. Radiat. Transfer | JQSRAE
Journal of Quantitative Spectroscopy & Radiative Transfer
J. Radioanal. Nucl. Chem. | JRNCDM
Journal of Radioanalytical and Nuclear Chemistry
J. Raman Spectrosc. | JRSPAF
Journal of Raman Spectroscopy
J. Recept. Signal Transduction | JRSTCT
Journal of Receptors and Signal Transduction
J. Reinf. Plast. Compos. | JRPCDW
Journal of Reinforced Plastics and Composites
J. Res. Updates Polym. Sci. | JRUPAP
Journal of Research Updates in Polymer Science
J. Rheol. (Melville, NY, U. S.) | JORHD2
Journal of Rheology (Melville, NY, United States)
J. Sep. Sci. | JSSCCJ
Journal of Separation Science
J. Sol-Gel Sci. Technol. | JSGTEC
Journal of Sol-Gel Science and Technology
J. Solid State Chem. | JSSCBI
Journal of Solid State Chemistry
J. Solid State Electrochem. | JSSEFS
Journal of Solid State Electrochemistry
J. Solution Chem. | JSLCAG
Journal of Solution Chemistry
J. Spectrosc. (N. Y., NY, U. S.) | JSNYAO
Journal of Spectroscopy (New York, NY, United States)
J. Steroid Biochem. Mol. Biol. | JSBBEZ
Journal of Steroid Biochemistry and Molecular Biology
J. Struct. Chem. | JSTCAM
Journal of Structural Chemistry
J. Struct. Funct. Genomics | JSFGAW
Journal of Structural and Functional Genomics
J. Sulfur Chem. | JSCOFC
Journal of Sulfur Chemistry
J. Supercond. Novel Magn. | JSNMBN
Journal of Superconductivity and Novel Magnetism
J. Supercrit. Fluids | JSFLEH
Journal of Supercritical Fluids
J. Surf. Invest.: X-Ray, Synchrotron Neutron Tech. | JSIXBV
Journal of Surface Investigation: X-Ray, Synchrotron and Neutron Techniques
J. Surfactants Deterg. | JSDEFL
Journal of Surfactants and Detergents
J. Sustainable Cem.-Based Mater. | JSCMD4
Journal of Sustainable Cement-Based Materials
J. Theor. Comput. Chem. | JTCCAC
Journal of Theoretical and Computational Chemistry
J. Therm. Anal. Calorim. | JTACF7
Journal of Thermal Analysis and Calorimetry
J. Thermodyn. Catal. | JTCOAE
Journal of Thermodynamics & Catalysis
J. Thermophys. Heat Transfer | JTHTEO
Journal of Thermophysics and Heat Transfer
J. Toxicol. Environ. Health, Part A | JTEHF8
Journal of Toxicology and Environmental Health, Part A: Current Issues
J. Toxicol. Environ. Health, Part B | JTECFR
Journal of Toxicology and Environmental Health, Part B: Critical Reviews
J. Vac. Sci. Technol., A | JVTAD6
Journal of Vacuum Science & Technology, A: Vacuum, Surfaces, and Films
J. Vac. Sci. Technol., B: Nanotechnol. Microelectron.: Mater., Process., Meas., Phenom. | JVSTCN
Journal of Vacuum Science & Technology, B: Nanotechnology & Microelectronics: Materials, Processing, Measurement, & Phenomena
J. Vinyl Addit. Technol. | JVATF4
Journal of Vinyl and Additive Technology
J. Virol. Methods | JVMEDH
Journal of Virological Methods
J. Virol. | JOVIAM
Journal of Virology
J. Volcanol. Geotherm. Res. | JVGRDQ
Journal of Volcanology and Geothermal Research
J. Wood Chem. Technol. | JWCTDJ
Journal of Wood Chemistry and Technology
J. Am. Ceram. Soc. | JACTAW
Journal of the American Ceramic Society
J. Am. Chem. Soc. | JACSAT
Journal of the American Chemical Society
J. Am. Oil Chem. Soc. | JAOCA7
Journal of the American Oil Chemists' Society
J. Am. Soc. Mass Spectrom. | JAMSEF
Journal of the American Society for Mass Spectrometry
J. Am. Soc. Brew. Chem. | JSBCD3
Journal of the American Society of Brewing Chemists
J. Am. Stat. Assoc. | JSTNAL
Journal of the American Statistical Association
J. Braz. Chem. Soc. | JOCSET
Journal of the Brazilian Chemical Society
J. Ceram. Soc. Jpn. | JCSJEW
Journal of the Ceramic Society of Japan
J. Chem. Soc. Pak. | JCSPDF
Journal of the Chemical Society of Pakistan
J. Chil. Chem. Soc. | JCCSCB
Journal of the Chilean Chemical Society
J. Chin. Adv. Mater. Soc. | JCAMCH
Journal of the Chinese Advanced Materials Society
J. Chin. Chem. Soc. (Weinheim, Ger.) | JCCTAC
Journal of the Chinese Chemical Society (Weinheim, Germany)
J. Electrochem. Soc. | JESOAN
Journal of the Electrochemical Society
J. Energy Inst. | JEIOB8
Journal of the Energy Institute
J. Eur. Ceram. Soc. | JECSER
Journal of the European Ceramic Society
J. Indian Chem. Soc. | JICSAH
Journal of the Indian Chemical Society
J. Inst. Chem. (India) | JOICA7
Journal of the Institution of Chemists (India)
J. Jpn. Pet. Inst. | JJPIAP
Journal of the Japan Petroleum Institute
J. Korean Ceram. Soc. | JKCSBW
Journal of the Korean Ceramic Society
J. Korean Chem. Soc. | JKCSEZ
Journal of the Korean Chemical Society
J. Opt. Soc. Am. B | JOBPDE
Journal of the Optical Society of America B: Optical Physics
J. Sci. Food Agric. | JSFAAE
Journal of the Science of Food and Agriculture
J. Serb. Chem. Soc. | JSCSEN
Journal of the Serbian Chemical Society
J. Soc. Inorg. Mater., Jpn. | JSIJFR
Journal of the Society of Inorganic Materials, Japan
J. Taiwan Inst. Chem. Eng. | JTICA8
Journal of the Taiwan Institute of Chemical Engineers
KGK, Kautsch. Gummi Kunstst. | KKGKB5
KGK, Kautschuk Gummi Kunststoffe
Kagaku Kogaku Ronbunshu | KKRBAW
Kem. Ind. | KJUIAR
Kemija u Industriji
Khim. Prom-st. Segodnya | KPSHBN
Khimicheskaya Promyshlennost Segodnya
Khim. Tekhnol. Vody | KTVODL
Khimiya i Tekhnologiya Vody
Khim. Interesakh Ustoich. Razvit. | KIURFI
Khimiya v Interesakh Ustoichivogo Razvitiya
Kinet. Catal. | KICAA8
Kinetics and Catalysis
Kobunshi Ronbunshu | KBRBA3
Korean J. Chem. Eng. | KJCHE6
Korean Journal of Chemical Engineering
LCGC North Am. | LNACBH
LCGC North America
LWT--Food Sci. Technol. | LSTWB3
LWT--Food Science and Technology
Lab Chip | LCAHAM
Lab on a Chip
Lab. Anim. | LBANAX
Laboratory Animals
Langmuir | LANGD5
Laser Part. Beams | LPBEDA
Laser and Particle Beams
Latv. Kim. Z. | LKZUE8
Latvijas Kimijas Zurnals
Lett. Drug Des. Discovery | LDDDAW
Letters in Drug Design & Discovery
Lett. Org. Chem. | LOCEC7
Letters in Organic Chemistry
Life Sci. | LIFSAK
Life Sciences
Light: Sci. Appl. | LSAIAZ
Light: Science & Applications
Linchan Huaxue Yu Gongye | LHYGD7
Lipids | LPDSAP
Liq. Cryst. | LICRE6
Liquid Crystals
Liq. Cryst. Rev. | LCRIA8
Liquid Crystals Reviews
Lithos | LITHAN
Lung Cancer Manage. | LCMUAJ
Lung Cancer Management
MRS Commun. | MCROF8
MRS Communications
MRS Online Proc. Libr. | MOPLH7
MRS Online Proceedings Library
Macromol. Biosci. | MBAIBU
Macromolecular Bioscience
Macromol. Chem. Phys. | MCHPES
Macromolecular Chemistry and Physics
Macromol. Mater. Eng. | MMENFA
Macromolecular Materials and Engineering
Macromol. Rapid Commun. | MRCOE3
Macromolecular Rapid Communications
Macromol. React. Eng. | MREAD4
Macromolecular Reaction Engineering
Macromol. Res. | MRAECT
Macromolecular Research
Macromol. Symp. | MSYMEC
Macromolecular Symposia
Macromol. Theory Simul. | MTHSEK
Macromolecular Theory and Simulations
Macromolecules (Washington, DC, U. S.) | MAMOBX
Macromolecules (Washington, DC, United States)
Magnesium Res. | MAGREF
Magnesium Research
Magn. Reson. Chem. | MRCHEG
Magnetic Resonance in Chemistry
Main Group Chem. | MGCHE7
Main Group Chemistry
Main Group Met. Chem. | MGMCE8
Main Group Metal Chemistry
Mar. Biotechnol. | MABIFW
Marine Biotechnology
Mar. Chem. | MRCHBD
Marine Chemistry
Mar. Environ. Res. | MERSDW
Marine Environmental Research
Mar. Pollut. Bull. | MPNBAZ
Marine Pollution Bulletin
Mater. Charact. | MACHEX
Materials Characterization
Mater. Chem. Phys. | MCHPDR
Materials Chemistry and Physics
Mater. Express | MEAXBS
Materials Express
Mater. Focus | MFAOC9
Materials Focus
Mater. Horiz. | MHAOBM
Materials Horizons
Mater. Lett. | MLETDJ
Materials Letters
Mater. Perform. Charact. | MPCACD
Materials Performance and Characterization
Mater. Res. Bull. | MRBUAC
Materials Research Bulletin
Mater. Res. Express | MREAC3
Materials Research Express
Mater. Res. Innovations | MRINFV
Materials Research Innovations
Mater. Res. Lett. | MRLAC4
Materials Research Letters
Mater. Sci. Eng., A | MSAPE3
Materials Science & Engineering, A: Structural Materials: Properties, Microstructure and Processing
Mater. Sci. Eng., B | MSBTEK
Materials Science & Engineering, B: Advanced Functional Solid-State Materials
Mater. Sci. Eng., C | MSCEEE
Materials Science & Engineering, C: Materials for Biological Applications
Mater. Sci. Technol. | MSCTEP
Materials Science and Technology
Mater. Sci. Semicond. Process. | MSSPFQ
Materials Science in Semiconductor Processing
Mater. Trans. | MTARCE
Materials Transactions
Mater. Corros. | MTCREQ
Materials and Corrosion
Mater. Manuf. Processes | MMAPET
Materials and Manufacturing Processes
Matrix Biol. | MTBOEC
Matrix Biology
Meas. Sci. Technol. | MSTCEP
Measurement Science and Technology
Mech. Dev. | MEDVE6
Mechanisms of Development
MedChemComm | MCCEAY
Med. Chem. (Sharjah, United Arab Emirates) | MCEHAJ
Medicinal Chemistry (Sharjah, United Arab Emirates)
Med. Chem. Res. | MCREEB
Medicinal Chemistry Research
Membranes (Basel, Switz.) | MBSEB6
Membranes (Basel, Switzerland)
Mendeleev Commun. | MENCEX
Mendeleev Communications
Metab. Eng. | MEENFM
Metabolic Engineering
Metab., Clin. Exp. | METAAJ
Metabolism, Clinical and Experimental
Metabolites | METALU
Metabolomics | METAHQ
Met. Sci. Heat Treat. | MHTRAN
Metal Science and Heat Treatment
Metallofiz. Noveishie Tekhnol. | MNTEEU
Metallofizika i Noveishie Tekhnologii
Metall. Mater. Trans. A | MMTAEB
Metallurgical and Materials Transactions A: Physical Metallurgy and Materials Science
Metall. Mater. Trans. B | MTBSEO
Metallurgical and Materials Transactions B: Process Metallurgy and Materials Processing Science
Metals (Basel, Switz.) | MBSEC7
Metals (Basel, Switzerland)
Meteorit. Planet. Sci. | MPSCFY
Meteoritics & Planetary Science
Methods (Amsterdam, Neth.) | MTHDE9
Methods (Amsterdam, Netherlands)
Microbiology (London, U. K.) | MROBEO
Microbiology (London, United Kingdom)
Microbiology (Moscow, Russ. Fed.) | MIBLAO
Microbiology (Moscow, Russian Federation)
Microbiol. Immunol. | MIIMDV
Microbiology and Immunology
Microchem. J. | MICJAN
Microchemical Journal
Microchim. Acta | MIACAQ
Microchimica Acta
Microelectron. Eng. | MIENEF
Microelectronic Engineering
Microporous Mesoporous Mater. | MIMMFJ
Microporous and Mesoporous Materials
Microsc. Microanal. | MIMIF7
Microscopy and Microanalysis
Miner. Deposita | MIDEBE
Mineralium Deposita
Mineral. Petrol. | MIPEE9
Mineralogy and Petrology
Miner. Eng. | MENGEB
Minerals Engineering
Mini-Rev. Med. Chem. | MMCIAE
Mini-Reviews in Medicinal Chemistry
Mini-Rev. Org. Chem. | MOCIBT
Mini-Reviews in Organic Chemistry
Mitochondrial DNA | MDINCW
Mitochondrion | MITOCN
Mod. Phys. Lett. B | MPLBET
Modern Physics Letters B
Mod. Res. Catal. | MRCOCZ
Modern Research in Catalysis
Mol. Biochem. Parasitol. | MBIPDP
Molecular & Biochemical Parasitology
Mol. Cell. Proteomics | MCPOBS
Molecular & Cellular Proteomics
Mol. Cell. Toxicol. | MCTODG
Molecular & Cellular Toxicology
Mol. BioSyst. | MBOIBW
Molecular BioSystems
Mol. Biol. (Moscow, Russ. Fed., Engl. Ed.) | MOLBBJ
Molecular Biology (Moscow, Russian Federation, English Edition)
Mol. Biol. Rep. | MLBRBU
Molecular Biology Reports
Mol. Biol. Evol. | MBEVEO
Molecular Biology and Evolution
Mol. Biol. Cell | MBCEEV
Molecular Biology of the Cell
Mol. Biotechnol. | MLBOEO
Molecular Biotechnology
Mol. Cancer Res. | MCROC5
Molecular Cancer Research
Mol. Cancer Ther. | MCTOCF
Molecular Cancer Therapeutics
Mol. Carcinog. | MOCAE8
Molecular Carcinogenesis
Mol. Cell | MOCEFL
Molecular Cell
Mol. Cryst. Liq. Cryst. | MCLCD8
Molecular Crystals and Liquid Crystals
Mol. Diversity | MODIF4
Molecular Diversity
Mol. Endocrinol. | MOENEN
Molecular Endocrinology
Mol. Genet. Genomics | MGGOAA
Molecular Genetics and Genomics
Mol. Genet. Metab. | MGMEFF
Molecular Genetics and Metabolism
Mol. Immunol. | MOIMD5
Molecular Immunology
Mol. Inf. | MIONBS
Molecular Informatics
Mol. Med. (Manhasset, NY, U. S.) Molecular Medicine (Manhasset, NY, United States) | MOMEF3
Mol. Med. Rep. Molecular Medicine Reports | MMROA5
Mol. Membr. Biol. Molecular Membrane Biology | MMEBE7
Mol. Metab. Molecular Metabolism | MMOEAS
Mol. Microbiol. Molecular Microbiology | MOMIEE
Mol. Neurobiol. Molecular Neurobiology | MONBEW
Mol. Nutr. Food Res. Molecular Nutrition & Food Research | MNFRCV
Mol. Pharmaceutics Molecular Pharmaceutics | MPOHBP
Mol. Pharmacol. Molecular Pharmacology | MOPMA3
Mol. Phys. Molecular Physics | MOPHAM
Mol. Plant Molecular Plant | MPOLA2
Mol. Plant-Microbe Interact. Molecular Plant-Microbe Interactions | MPMIEL
Mol. Reprod. Dev. Molecular Reproduction & Development | MREDEE
Mol. Simul. Molecular Simulation | MOSIEA
Mol. Ther. Molecular Therapy | MTOHCK
Mol. Ther.--Methods Clin. Dev. Molecular Therapy--Methods & Clinical Development | MTCDAE
Mol. Ther.--Nucleic Acids Molecular Therapy--Nucleic Acids | MTAOC5
Mol. Cell. Biochem. Molecular and Cellular Biochemistry | MCBIB8
Mol. Cell. Biol. Molecular and Cellular Biology | MCEBD4
Mol. Cell. Endocrinol. Molecular and Cellular Endocrinology | MCEND6
Mol. Cell. Neurosci. Molecular and Cellular Neuroscience | MOCNED
Mol. Cell. Probes Molecular and Cellular Probes | MCPRE6
Molecules | MOLEFW
Mol. Cells Molecules and Cells | MOCEEK
Monatsh. Chem. Monatshefte fuer Chemie | MOCMB7
Mucosal Immunol. Mucosal Immunology | MIUMAK
Mutagenesis | MUTAEX
Mutat. Res., Fundam. Mol. Mech. Mutagen. Mutation Research, Fundamental and Molecular Mechanisms of Mutagenesis | MUREAV
Mutat. Res., Genet. Toxicol. Environ. Mutagen. Mutation Research, Genetic Toxicology and Environmental Mutagenesis | MRGMFI
Mutat. Res., Rev. Mutat. Res. Mutation Research, Reviews in Mutation Research | MRRRFK
Nano | NANOFJ
Nano Energy | NEANCA
Nano Lett. Nano Letters | NALEFD
Nano Sci. Nano Technol.: Indian J. Nano Science and Nano Technology: An Indian Journal | NSNTBK
Nanomaterials | NANOKO
Nanomedicine (London, U. K.) Nanomedicine (London, United Kingdom) | NLUKAC
Nanomedicine (N. Y., NY, U. S.) Nanomedicine (New York, NY, United States) | NANOBF
Nanoscale | NANOHL
Nat. Prod. Rep. Natural Product Reports | NPRRDF
Nat. Prod. Res. Natural Product Research | NPRAAT
Nat. Prod. Sci. Natural Product Sciences | NPSCFB
Nat. Prod. J. Natural Products Journal | NPJACP
Nature (London, U. K.) Nature (London, United Kingdom) | NATUAS
Nat. Biotechnol. Nature Biotechnology | NABIF9
Nat. Cell Biol. Nature Cell Biology | NCBIFN
Nat. Chem. Biol. Nature Chemical Biology | NCBABT
Nat. Chem. Nature Chemistry | NCAHBB
Nat. Commun. Nature Communications | NCAOBW
Nat. Genet. Nature Genetics | NGENEC
Nat. Geosci. Nature Geoscience | NGAEBU
Nat. Immunol. Nature Immunology | NIAMCZ
Nat. Mater. Nature Materials | NMAACR
Nat. Med. (N. Y., NY, U. S.) Nature Medicine (New York, NY, United States) | NAMEFI
Nat. Methods Nature Methods | NMAEA3
Nat. Nanotechnol. Nature Nanotechnology | NNAABX
Nat. Neurosci. Nature Neuroscience | NANEFN
Nat. Photonics Nature Photonics | NPAHBY
Nat. Phys. Nature Physics | NPAHAX
Nat. Protoc. Nature Protocols | NPARDW
Nat. Rev. Cancer Nature Reviews Cancer | NRCAC4
Nat. Rev. Drug Discovery Nature Reviews Drug Discovery | NRDDAG
Nat. Rev. Genet. Nature Reviews Genetics | NRGAAM
Nat. Rev. Immunol. Nature Reviews Immunology | NRIABX
Nat. Rev. Microbiol. Nature Reviews Microbiology | NRMACK
Nat. Rev. Mol. Cell Biol. Nature Reviews Molecular Cell Biology | NRMCBP
Nat. Rev. Neurosci. Nature Reviews Neuroscience | NRNAAN
Nat. Struct. Mol. Biol. Nature Structural & Molecular Biology | NSMBCU
Naturwissenschaften | NATWAY
Naunyn-Schmiedeberg's Arch. Pharmacol. Naunyn-Schmiedeberg's Archives of Pharmacology | NSAPCC
Neues Jahrb. Mineral., Abh. Neues Jahrbuch fuer Mineralogie, Abhandlungen | NJMIAK
NeuroImmunoModulation | NROIEM
NeuroMol. Med. NeuroMolecular Medicine | NMEEAN
Neurochem. Res. Neurochemical Research | NEREDZ
Neurochem. Int. Neurochemistry International | NEUIDS
Neuroendocrinology | NUNDAJ
Neuron | NERNET
Neuropeptides (Oxford, U. K.) Neuropeptides (Oxford, United Kingdom) | NRPPDD
Neuropharmacology | NEPHBW
Neuroscience (Amsterdam, Neth.) Neuroscience (Amsterdam, Netherlands) | NRSCDN
Neurosci. Lett. Neuroscience Letters | NELED5
Neurotoxicol. Teratol. Neurotoxicology and Teratology | NETEEC
New Biotechnol. New Biotechnology | NBEIBR
N. Engl. J. Med. New England Journal of Medicine | NEJMAG
New J. Chem. New Journal of Chemistry | NJCHE5
Nihon Reoroji Gakkaishi | NRGIAC
Nippon Kinzoku Gakkaishi | NIKGAV
Nitric Oxide | NIOXF5
Nord. Pulp Pap. Res. J. Nordic Pulp & Paper Research Journal | NPPJEG
Nucl. Eng. Des. Nuclear Engineering and Design | NEDEAU
Nucl. Fusion Nuclear Fusion | NUFUAU
Nucl. Instrum. Methods Phys. Res., Sect. A Nuclear Instruments & Methods in Physics Research, Section A: Accelerators, Spectrometers, Detectors, and Associated Equipment | NIMAER
Nucl. Instrum. Methods Phys. Res., Sect. B Nuclear Instruments & Methods in Physics Research, Section B: Beam Interactions with Materials and Atoms | NIMBEU
Nucl. Med. Biol. Nuclear Medicine and Biology | NMBIEO
Nucl. Phys. A Nuclear Physics A | NUPABL
Nucl. Phys. B Nuclear Physics B | NUPBBO
Nucleic Acid Ther. Nucleic Acid Therapeutics | NATUCU
Nucleic Acids Res. Nucleic Acids Research | NARHAD
Nucleosides, Nucleotides Nucleic Acids Nucleosides, Nucleotides & Nucleic Acids | NNNAFY
Nukleonika | NUKLAS
Nutr. Res. (N. Y., NY, U. S.) Nutrition Research (New York, NY, United States) | NTRSDC
OMICS | OMICAE
Oncogene | ONCNES
Open J. Inorg. Non-Met. Mater. Open Journal of Inorganic Non-Metallic Materials | OJINAQ
Open J. Med. Chem. Open Journal of Medicinal Chemistry | OJMCAD
Open J. Org. Polym. Mater. Open Journal of Organic Polymer Materials | OJOPAS
Open J. Polym. Chem. Open Journal of Polymer Chemistry | OJPCBT
Open J. Synth. Theory Appl. Open Journal of Synthesis Theory and Applications | OJSTAQ
Opt. Commun. Optics Communications | OPCOB8
Opt. Spectrosc. Optics and Spectroscopy | OPSUA3
Org. Biomol. Chem. Organic & Biomolecular Chemistry | OBCRAK
Org. Chem. Front. Organic Chemistry Frontiers | OCFRA8
Org. Chem. Int. Organic Chemistry International | OCIRDQ
Org. Electron. Organic Electronics | OERLAU
Org. Geochem. Organic Geochemistry | ORGEDE
Org. Lett. Organic Letters | ORLEF7
Org. Prep. Proced. Int. Organic Preparations and Procedures International | OPPIAK
Org. Process Res. Dev. Organic Process Research & Development | OPRDFK
Org. Synth. Organic Syntheses | ORSYAT
Org. Med. Chem. Lett. Organic and Medicinal Chemistry Letters | OMCLBC
Organometallics | ORGND7
Orient. J. Chem. Oriental Journal of Chemistry | OJCHEG
Oxid. Commun. Oxidation Communications | OXCODW
Oxid. Met. Oxidation of Metals | OXMEAF
Ozone: Sci. Eng. Ozone: Science & Engineering | OZSEDS
PLoS Biol. PLoS Biology | PBLIBG
PLoS Comput. Biol. PLoS Computational Biology | PCBLBG
PLoS Genet. PLoS Genetics | PGLEB5
PLoS One | POLNCL
PLoS Pathog. PLoS Pathogens | PPLACN
PMSE Prepr. PMSE Preprints | PPMRA9
Part. Sci. Technol. Particulate Science and Technology | PTCHDS
Peptides (N. Y., NY, U. S.) Peptides (New York, NY, United States) | PPTDD5
Pers. Med. Personalized Medicine | PMEECD
Pest Manage. Sci. Pest Management Science | PMSCFC
Pestic. Biochem. Physiol. Pesticide Biochemistry and Physiology | PCBPBS
Pet. Chem. Petroleum Chemistry | PHEME4
Pet. Sci. Technol. Petroleum Science and Technology | PSTEFV
Pfluegers Arch. Pfluegers Archiv | PFLABK
Pharma Chem. Pharma Chemica | PCHHAX
Pharm. Chem. J. Pharmaceutical Chemistry Journal | PCJOAU
Pharm. Dev. Technol. Pharmaceutical Development and Technology | PDTEFS
Pharm. Nanotechnol. Pharmaceutical Nanotechnology | PNHABM
Pharm. Pat. Anal. Pharmaceutical Patent Analyst | PPAHCN
Pharm. Res. Pharmaceutical Research | PHREEB
Pharm. Sin. Pharmacia Sinica | PSHIBD
Pharmacogenet. Genomics Pharmacogenetics and Genomics | PGHEAI
Pharmacogenomics | PARMFL
Pharmacogenomics J. Pharmacogenomics Journal | PJHOAZ
Pharmacology | PHMGBN
Pharmacol. Ther. Pharmacology & Therapeutics | PHTHDT
Pharmacol., Biochem. Behav. Pharmacology, Biochemistry and Behavior | PBBHAU
Pharmazie | PHARAT
Phase Transitions | PHTRDP
Philos. Mag. Philosophical Magazine | PMHABF
Philos. Mag. Lett. Philosophical Magazine Letters | PMLEEG
Phosphorus, Sulfur Silicon Relat. Elem. Phosphorus, Sulfur and Silicon and the Related Elements | PSSLEC
Photochem. Photobiol. Sci. Photochemical & Photobiological Sciences | PPSHCB
Photochem. Photobiol. Photochemistry and Photobiology | PHCBAP
Photosynth. Res. Photosynthesis Research | PHRSDI
Phys. B (Amsterdam, Neth.) Physica B: Condensed Matter (Amsterdam, Netherlands) | PHYBE3
Phys. C (Amsterdam, Neth.) Physica C: Superconductivity and Its Applications (Amsterdam, Netherlands) | PHYCE6
Phys. Scr. Physica Scripta | PHSTBO
Phys. Scr., T Physica Scripta, T | PHSTER
Phys. Status Solidi A Physica Status Solidi A: Applications and Materials Science | PSSABA
Phys. Status Solidi B Physica Status Solidi B: Basic Solid State Physics | PSSBBD
Phys. Status Solidi C Physica Status Solidi C: Current Topics in Solid State Physics | PSSCGL
Phys. Status Solidi RRL Physica Status Solidi RRL: Rapid Research Letters | PSSRCS
Phys. Chem. Chem. Phys. Physical Chemistry Chemical Physics | PPCPFQ
Phys. Rev. A: At., Mol., Opt. Phys. Physical Review A: Atomic, Molecular, and Optical Physics | PLRAAN
Phys. Rev. Appl. Physical Review Applied | PRAHB2
Phys. Rev. B: Condens. Matter Mater. Phys. Physical Review B: Condensed Matter and Materials Physics | PRBMDO
Phys. Rev. C: Nucl. Phys. Physical Review C: Nuclear Physics | PRVCAN
Phys. Rev. D: Part., Fields, Gravitation, Cosmol. Physical Review D: Particles, Fields, Gravitation, and Cosmology | PRDPC8
Phys. Rev. E: Stat., Nonlinear, Soft Matter Phys. Physical Review E: Statistical, Nonlinear, and Soft Matter Physics | PRESCM
Phys. Rev. Lett. Physical Review Letters | PRLTAO
Phys. Rev. X Physical Review X | PRXHAE
Phys. Lett. A Physics Letters A | PYLAAG
Phys. Lett. B Physics Letters B | PYLBAJ
Phys. Chem. Liq. Physics and Chemistry of Liquids | PCLQAC
Phys. Chem. Miner. Physics and Chemistry of Minerals | PCMIDU
Phys. At. Nucl. Physics of Atomic Nuclei | PANUEO
Phys. Fluids Physics of Fluids | PHFLE6
Phys. Plasmas Physics of Plasmas | PHPAEN
Phys. Solid State Physics of the Solid State | PSOSED
Physiol. Plant. Physiologia Plantarum | PHPLAI
Physiol. Behav. Physiology & Behavior | PHBHA4
Phytochem. Anal. Phytochemical Analysis | PHANEL
Phytochemistry (Elsevier) | PYTCAS
Phytochem. Rev. Phytochemistry Reviews | PRHEBS
Plant Cell | PLCEEW
Plant Cell Rep. Plant Cell Reports | PCRPD8
Plant Growth Regul. Plant Growth Regulation | PGRED3
Plant J. Plant Journal | PLJUED
Plant Mol. Biol. Plant Molecular Biology | PMBIDB
Plant Physiol. Plant Physiology | PLPHAY
Plant Physiol. Biochem. (Issy-les-Moulineaux, Fr.) Plant Physiology and Biochemistry (Issy-les-Moulineaux, France) | PPBIEX
Plant Sci. (Shannon, Irel.) Plant Science (Shannon, Ireland) | PLSCE4
Plant Cell Physiol. Plant and Cell Physiology | PCPHA5
Plant Soil Plant and Soil | PLSOA2
Planta | PLANAB
Planta Med. Planta Medica | PLMEAA
Plasma Chem. Plasma Process. Plasma Chemistry and Plasma Processing | PCPPDW
Plasma Processes Polym. Plasma Processes and Polymers | PPPLA6
Plasmid | PLSMDX
Plast. Reconstr. Surg. Plastic and Reconstructive Surgery | PRSUAS
Plast. Massy Plasticheskie Massy | PLMSAI
Plast., Rubber Compos. Plastics, Rubber and Composites | PRUCFN
Platelets | PLTEEF
Pol. J. Chem. Technol. Polish Journal of Chemical Technology | PJCTAP
Polycyclic Aromat. Compd. Polycyclic Aromatic Compounds | PARCEO
Polyhedron | PLYHDE
Polymer | POLMAG
Polymer (Korea) | POLLDG
Polym. Bull. (Heidelberg, Ger.) Polymer Bulletin (Heidelberg, Germany) | POBUDR
Polym. Chem. Polymer Chemistry | PCOHC2
Polym. Compos. Polymer Composites | PCOMDI
Polym. Degrad. Stab. Polymer Degradation and Stability | PDSTDW
Polym. Eng. Sci. Polymer Engineering & Science | PYESAZ
Polym. Int. Polymer International | PLYIEI
Polym. J. (Tokyo, Jpn.) Polymer Journal (Tokyo, Japan) | POLJB8
Polym. Prepr. (Am. Chem. Soc., Div. Polym. Chem.) Polymer Preprints (American Chemical Society, Division of Polymer Chemistry) | ACPPAY
Polym. Rev. (Philadelphia, PA, U. S.) Polymer Reviews (Philadelphia, PA, United States) | PRPPCY
Polym. Sci., Ser. A Polymer Science, Series A | PSSAFE
Polym. Sci., Ser. B Polymer Science, Series B | PSSBFH
Polym. Sci., Ser. C Polymer Science, Series C | PSSCCH
Polym. Sci., Ser. D Polymer Science, Series D | PSSDCK
Polym. Test. Polymer Testing | POTEDZ
Polym.-Plast. Technol. Eng. Polymer-Plastics Technology and Engineering | PPTEC7
Polym. Polym. Compos. Polymers & Polymer Composites | PPOCEC
Polymers (Basel, Switz.) Polymers (Basel, Switzerland) | POLYCK
Polym. Adv. Technol. Polymers for Advanced Technologies | PADTE5
Powder Diffr. Powder Diffraction | PODIE2
Powder Metall. Powder Metallurgy | PWMTAU
Powder Metall. Met. Ceram. Powder Metallurgy and Metal Ceramics | PMMCEF
Powder Technol. Powder Technology | POTEBX
Pract. Spectrosc. Practical Spectroscopy | PSPED9
Precambrian Res. Precambrian Research | PCBRBY
Prep. Biochem. Biotechnol. Preparative Biochemistry & Biotechnology | PBBIF4
Prepr. - Am. Chem. Soc., Div. Energy Fuels Preprints - American Chemical Society, Division of Energy & Fuels | PACSCT
Procedia Mater. Sci. Procedia Materials Science | PMSREM
Proc. Natl. Acad. Sci. U. S. A. Proceedings of the National Academy of Sciences of the United States of America | PNASA6
Process Biochem. (Oxford, U. K.) Process Biochemistry (Oxford, United Kingdom) | PBCHE5
Process Saf. Environ. Prot. Process Safety and Environmental Protection | PSEPEM
Prog. Colloid Polym. Sci. Progress in Colloid and Polymer Science | PCPSD7
Prog. Cryst. Growth Charact. Mater. Progress in Crystal Growth and Characterization of Materials | PCGMED
Prog. Inorg. Chem. Progress in Inorganic Chemistry | PIOCAR
Prog. Nucl. Magn. Reson. Spectrosc. Progress in Nuclear Magnetic Resonance Spectroscopy | PNMRAT
Prog. Org. Coat. Progress in Organic Coatings | POGCAT
Prog. Polym. Sci. Progress in Polymer Science | PRPSB8
Prog. React. Kinet. Mech. Progress in Reaction Kinetics and Mechanism | PRKMF3
Prog. Solid State Chem. Progress in Solid State Chemistry | PSSTAW
Prog. Surf. Sci. Progress in Surface Science | PSSFBP
Propellants, Explos., Pyrotech. Propellants, Explosives, Pyrotechnics | PEPYD5
Prostaglandins Other Lipid Mediators Prostaglandins and Other Lipid Mediators | POLMFL
Prostaglandins, Leukotrienes Essent. Fatty Acids Prostaglandins, Leukotrienes and Essential Fatty Acids | PLEAEU
Prot. Met. Phys. Chem. Surf. Protection of Metals and Physical Chemistry of Surfaces | PMPCBR
Protein Pept. Lett. Protein & Peptide Letters | PPELEN
Protein Eng., Des. Sel. Protein Engineering, Design & Selection | PEDSBR
Protein Expression Purif. Protein Expression and Purification | PEXPEJ
Protein J. Protein Journal | PJROAH
Protein Sci. Protein Science | PRCIEI
Proteins: Struct., Funct., Bioinf. Proteins: Structure, Function, and Bioinformatics | PSFBAF
Proteomics | PROTC7
Proteomics: Clin. Appl. Proteomics: Clinical Applications | PCARCU
Przem. Chem. Przemysl Chemiczny | PRCHAB
Psychopharmacology (Heidelberg, Ger.) Psychopharmacology (Heidelberg, Germany) | PSCHDL
Pteridines | PTRDEO
Pulm. Pharmacol. Ther. Pulmonary Pharmacology & Therapeutics | PPTHFJ
Pure Appl. Chem. Pure and Applied Chemistry | PACHAS
Purinergic Signalling | PSUIA9
Quantum Electron. Quantum Electronics | QUELEZ
Quim. Nova Quimica Nova | QUNODK
RNA | RNARFU
RSC Adv. RSC Advances | RSCACL
Radiat. Eff. Defects Solids Radiation Effects and Defects in Solids | REDSEI
Radiat. Meas. Radiation Measurements | RMEAEP
Radiat. Phys. Chem. Radiation Physics and Chemistry | RPCHDM
Radiat. Res. Radiation Research | RAREAE
Radiochemistry (Moscow, Russ. Fed.) Radiochemistry (Moscow, Russian Federation) | RDIOEO
Radiochim. Acta Radiochimica Acta | RAACAP
Radioprotection | RAPRBA
Ranliao Huaxue Xuebao | RHXUD8
Rapid Commun. Mass Spectrom. Rapid Communications in Mass Spectrometry | RCMSEF
Rare Met. (Beijing, China) Rare Metals (Beijing, China) | RARME8
React. Kinet., Mech. Catal. Reaction Kinetics, Mechanisms and Catalysis | RKMCAJ
React. Funct. Polym. Reactive & Functional Polymers | RFPOF6
Recent Adv. Cardiovasc. Drug Discovery Recent Advances in Cardiovascular Drug Discovery | RACDC6
Recent Adv. DNA Gene Sequences Recent Advances in DNA & Gene Sequences | RADGCK
Recent Pat. Anti-Cancer Drug Discovery Recent Patents on Anti-Cancer Drug Discovery | RPADDY
Recent Pat. Anti-Infect. Drug Discovery Recent Patents on Anti-Infective Drug Discovery | RPADCX
Recent Pat. Biotechnol. | RPBEB6
Recent Pat. CNS Drug Discovery Recent Patents on CNS Drug Discovery | RPCDC9
Recent Pat. Drug Delivery Formulation Recent Patents on Drug Delivery & Formulation | RPODBY
Recent Pat. Endocr., Metab. Immune Drug Discovery Recent Patents on Endocrine, Metabolic & Immune Drug Discovery | RPEMBB
Recent Pat. Inflammation Allergy Drug Discovery Recent Patents on Inflammation & Allergy Drug Discovery | RPIABT
Recent Pat. Nanotechnol. Recent Patents on Nanotechnology | RPNEBW
Redox Biol. Redox Biology | RBEIB3
Regener. Med. Regenerative Medicine | RMEECZ
Rengong Jingti Xuebao | RJXUEN
Reproduction (Bristol, U. K.) Reproduction (Bristol, United Kingdom) | RCUKBS
Reprod. Toxicol. Reproductive Toxicology | REPTED
Res. Chem. Intermed. Research on Chemical Intermediates | RCINEE
Rev. Sci. Instrum. Review of Scientific Instruments | RSINAK
Rev. Anal. Chem. Reviews in Analytical Chemistry | RACYAX
Rev. Inorg. Chem. Reviews in Inorganic Chemistry | RICHD7
Rev. Mex. Ing. Quim. Revista Mexicana de Ingenieria Quimica | RMIQBM
Rev. Peru. Quim. Ing. Quim. Revista Peruana de Quimica e Ingenieria Quimica | RPQIAO
Rev. Rom. Mater. Revista Romana de Materiale | RRMEB7
Rev. Chim. (Bucharest, Rom.) Revista de Chimie (Bucharest, Romania) | RCBUAU
Rev. Soc. Quim. Peru Revista de la Sociedad Quimica del Peru | RSQPAW
Rheol. Acta Rheologica Acta | RHEAAK
Rubber Chem. Technol. Rubber Chemistry and Technology | RCTEA4
Russ. Chem. Bull. Russian Chemical Bulletin | RCBUEY
Russ. Chem. Rev. Russian Chemical Reviews | RCRVAB
Russ. J. Appl. Chem. Russian Journal of Applied Chemistry | RJACEO
Russ. J. Bioorg. Chem. Russian Journal of Bioorganic Chemistry | RJBCET
Russ. J. Coord. Chem. Russian Journal of Coordination Chemistry | RJCCEY
Russ. J. Electrochem. Russian Journal of Electrochemistry | RJELE3
Russ. J. Gen. Chem. Russian Journal of General Chemistry | RJGCEK
Russ. J. Genet. Russian Journal of Genetics | RJGEEQ
Russ. J. Inorg. Chem. Russian Journal of Inorganic Chemistry | RJICAQ
Russ. J. Org. Chem. Russian Journal of Organic Chemistry | RJOCEQ
Russ. J. Phys. Chem. A Russian Journal of Physical Chemistry A | RJPCBS
Russ. J. Phys. Chem. B Russian Journal of Physical Chemistry B | RJPCCT
Russ. J. Plant Physiol. Russian Journal of Plant Physiology | RJPPE2
SAR QSAR Environ. Res. SAR and QSAR in Environmental Research | SQERED
SPE Prod. Oper. SPE Production & Operations | SPEPCW
SPE Reservoir Eval. Eng. SPE Reservoir Evaluation & Engineering | SREEFG
Science (Washington, DC, U. S.) Science (Washington, DC, United States) | SCIEAS
Sci. China: Chem. Science China: Chemistry | SCCCCS
Sci. Lett. Science Letters | SCIEFX
Sci. Adv. Mater. Science of Advanced Materials | SAMCCU
Sci. Synth., Knowl. Updates Science of Synthesis, Knowledge Updates | SSKUBT
Sci. Total Environ. Science of the Total Environment | STENDL
Sci. Pharm. Scientia Pharmaceutica | SCPHA4
Sci. Rep. Scientific Reports | SRCEC3
Scr. Mater. Scripta Materialia | SCMAF7
Seibutsu Kogaku Kaishi | SEKAEA
Semicond. Sci. Technol. Semiconductor Science and Technology | SSTEET
Semiconductors | SMICES
Sens. Actuators, A Sensors and Actuators, A: Physical | SAAPEB
Sens. Actuators, B Sensors and Actuators, B: Chemical | SABCEB
Sep. Sci. Technol. (Philadelphia, PA, U. S.) Separation Science and Technology (Philadelphia, PA, United States) | SSTEDS
Sep. Purif. Technol. Separation and Purification Technology | SPUTFP
Sepu | SEPUER
Shiyou Huagong | SHHUE8
Shiyou Xuebao, Shiyou Jiagong | SXSHEY
Shuichuli Jishu | SHJIEG
Silicon | SILIBU
Small | SMALBC
Soft Matter | SMOABF
Soil Biol. Biochem. Soil Biology & Biochemistry | SBIOAH
Soil Sci. Soil Science | SOSCAK
Soil Sci. Soc. Am. J. Soil Science Society of America Journal | SSSJD4
Sol. Energy Mater. Sol. Cells Solar Energy Materials & Solar Cells | SEMCEQ
Solid Fuel Chem. Solid Fuel Chemistry | SFCHDV
Solid State Commun. Solid State Communications | SSCOA4
Solid State Ionics | SSIOD3
Solid State Nucl. Magn. Reson. Solid State Nuclear Magnetic Resonance | SSNRE4
Solid State Sci. Solid State Sciences | SSSCFJ
Solid-State Electron. Solid-State Electronics | SSELA5
Solvent Extr. Res. Dev., Jpn. Solvent Extraction Research and Development, Japan | SERDEK
Solvent Extr. Ion Exch. Solvent Extraction and Ion Exchange | SEIEDB
S. Afr. J. Chem. South African Journal of Chemistry | SAJCDG
Spectrochim. Acta, Part A Spectrochimica Acta, Part A: Molecular and Biomolecular Spectroscopy | SAMCAS
Spectrochim. Acta, Part B Spectrochimica Acta, Part B: Atomic Spectroscopy | SAASBH
Spectrosc. Lett. Spectroscopy Letters | SPLEBX
Starch/Staerke | STARDD
Steel Res. Int. Steel Research International | SRITB9
Steroids | STEDAM
Struct. Chem. Structural Chemistry | STCHES
Struct. Dyn. Structural Dynamics | SDTYAE
Structure (Oxford, U. K.) Structure (Oxford, United Kingdom) | STRUE6
Supercond. Sci. Technol. Superconductor Science and Technology | SUSTEF
Superlattices Microstruct. Superlattices and Microstructures | SUMIEK
Supramol. Chem. Supramolecular Chemistry | SCHEER
Surf. Eng. Surface Engineering | SUENET
Surf. Rev. Lett. Surface Review and Letters | SRLEFH
Surf. Sci. Surface Science | SUSCAS
Surf. Sci. Rep. Surface Science Reports | SSREDI
Surf. Coat. Technol. Surface and Coatings Technology | SCTEEJ
Surf. Interface Anal. Surface and Interface Analysis | SIANDQ
Sustainable Chem. Processes Sustainable Chemical Processes | SCPUCB
Synapse (Hoboken, NJ, U. S.) Synapse (Hoboken, NJ, United States) | SYNAET
Synlett | SYNLES
Synthesis | SYNTBF
Synth. React. Inorg., Met.-Org., Nano-Met. Chem. Synthesis and Reactivity in Inorganic, Metal-Organic, and Nano-Metal Chemistry | SRIMDO
Synth. Commun. Synthetic Communications | SYNCAV
Synth. Met. Synthetic Metals | SYMEDZ
Taehan Kumsok, Chaeryo Hakhoechi | TKHABB
Talanta | TLNTA2
Tappi J. Tappi Journal | TAJODT
Tech. Phys. Technical Physics | TEPHEX
Tech. Phys. Lett. Technical Physics Letters | TPLEED
Tenside, Surfactants, Deterg. Tenside, Surfactants, Detergents | TSDEES
Tetrahedron | TETRAB
Tetrahedron Lett. Tetrahedron Letters | TELEAY
Tetrahedron: Asymmetry | TASYE3
Text. Res. J. Textile Research Journal | TRJOA9
Theor. Chem. Acc. Theoretical Chemistry Accounts | TCACFW
Theor. Found. Chem. Eng. Theoretical Foundations of Chemical Engineering | TFCEAU
Theor. Exp. Chem. Theoretical and Experimental Chemistry | TEXCAK
Ther. Delivery Therapeutic Delivery | TDHEA7
Thermochim. Acta Thermochimica Acta | THACAS
Thin Solid Films | THSFAP
Thromb. Res. Thrombosis Research | THBRAA
Tonkie Khim. Tekhnol. Tonkie Khimicheskie Tekhnologii | TKTOCC
Top. Catal. Topics in Catalysis | TOCAFI
Toxicol. Environ. Chem. Toxicological & Environmental Chemistry | TECSDY
Toxicol. Sci. Toxicological Sciences | TOSCF2
Toxicology | TXCYAC
Toxicol. In Vitro Toxicology In Vitro | TIVIEQ
Toxicol. Lett. Toxicology Letters | TOLED5
Toxicol. Mech. Methods Toxicology Mechanisms and Methods | TMMOCP
Toxicol. Res. (Cambridge, U. K.) Toxicology Research (Cambridge, United Kingdom) | TROEE8
Toxicol. Appl. Pharmacol. Toxicology and Applied Pharmacology | TXAPA9
Toxicon | TOXIA6
TrAC, Trends Anal. Chem. TrAC, Trends in Analytical Chemistry | TTAEDJ
Traffic (Oxford, U. K.) Traffic (Oxford, United Kingdom) | TRAFFA
Trans. Indian Ceram. Soc. Transactions of the Indian Ceramic Society | TICSAP
Trans. Inst. Met. Finish. Transactions of the Institute of Metal Finishing | TIMFA2
Transgenic Res. Transgenic Research | TRSEES
Transition Met. Chem. (Dordrecht, Neth.) Transition Metal Chemistry (Dordrecht, Netherlands) | TMCHDN
Trends Biochem. Sci. Trends in Biochemical Sciences | TBSCDB
Trends Biotechnol. Trends in Biotechnology | TRBIDM
Trends Carbohydr. Res. Trends in Carbohydrate Research | TCRRBM
Trends Endocrinol. Metab. Trends in Endocrinology and Metabolism | TENME4
Trends Environ. Anal. Chem. Trends in Environmental Analytical Chemistry | TEACA7
Trends Food Sci. Technol. Trends in Food Science & Technology | TFTEEH
Trends Genet. Trends in Genetics | TRGEE2
Trends Immunol. Trends in Immunology | TIRMAE
Trends Microbiol. Trends in Microbiology | TRMIEA
Trends Neurosci. Trends in Neurosciences | TNSCDR
Trends Pharmacol. Sci. Trends in Pharmacological Sciences | TPHSDY
Trends Plant Sci. Trends in Plant Science | TPSCF9
Tribol. Trans. Tribology Transactions | TRTRE4
Turk. J. Chem. Turkish Journal of Chemistry | TJCHE3
Ukr. Biochem. J. Ukrainian Biochemical Journal | UBJKAW
Ukr. Bioorg. Acta Ukrainica Bioorganica Acta | UBAKAL
Ukr. Khim. Zh. (Russ. Ed.) Ukrainskii Khimicheskii Zhurnal (Russian Edition) | UKZHAU
Ultramicroscopy | ULTRD6
Ultrason. Sonochem. Ultrasonics Sonochemistry | ULSOER
Vacuum | VACUAV
Vasc. Pharmacol. Vascular Pharmacology | VPAHAJ
Vestn. Mosk. Univ., Ser. 2: Khim. Vestnik Moskovskogo Universiteta, Seriya 2: Khimiya | VMUKA5
Vestn. S.-Peterb. Univ., Ser. 4: Fiz., Khim. Vestnik Sankt-Peterburgskogo Universiteta, Seriya 4: Fizika, Khimiya | VSUKEH
Vestsi Nats. Akad. Navuk Belarusi, Ser. Khim. Navuk Vestsi Natsyyanal'nai Akademii Navuk Belarusi, Seryya Khimichnykh Navuk | VNBNFX
Vib. Spectrosc. Vibrational Spectroscopy | VISPEK
Viral Immunol. Viral Immunology | VIIMET
Virology | VIRLAX
Virus Genes | VIGEET
Virus Res. Virus Research | VIREDF
Water Environ. Res. Water Environment Research | WAERED
Water Qual. Res. J. Can. Water Quality Research Journal of Canada | WQRCFA
Water Res. Water Research | WATRAG
Water Resour. Water Resources | WARED4
Water, Air, Soil Pollut. Water, Air, & Soil Pollution | WAPLAC
Wear | WEARAH
Women's Health | WHOEAZ
Wood Sci. Technol. Wood Science and Technology | WOSTBE
Wood Fiber Sci. Wood and Fiber Science | WFSCD4
World J. Condens. Matter Phys. World Journal of Condensed Matter Physics | WJCMAD
Wuji Huaxue Xuebao | WHUXEO
Wuli Huaxue Xuebao | WHXUEU
Wuli Xuebao | WLHPAR
X-Ray Spectrom. X-Ray Spectrometry | XRSPAX
X-Ray Struct. Anal. Online X-Ray Structure Analysis Online | XSAOBG
Xenobiotica | XENOBH
Yakhak Hoechi | YAHOA3
Yakugaku Zasshi | YKKZAJ
Yeast | YESTE3
Yingxiang Kexue Yu Guang Huaxue | YKYGAW
Yingyong Huaxue | YIHUED
Yosetsu Gakkai Ronbunshu | YGRODU
Youji Huaxue | YCHHDX
Yuki Gosei Kagaku Kyokaishi | YGKKAE
Z. Anorg. Allg. Chem. Zeitschrift fuer Anorganische und Allgemeine Chemie | ZAACAB
Z. Kristallogr. - Cryst. Mater. Zeitschrift fuer Kristallographie - Crystalline Materials | ZKCMAJ
Z. Kristallogr. - New Cryst. Struct. Zeitschrift fuer Kristallographie - New Crystal Structures | ZKNSFT
Z. Lebensm.-Unters. Forsch. A Zeitschrift fuer Lebensmittel-Untersuchung und -Forschung A: European Food Research and Technology | ZLFAFA
Z. Naturforsch., A: Phys. Sci. Zeitschrift fuer Naturforschung, A: Physical Sciences | ZNASEI
Z. Naturforsch., B: J. Chem. Sci. Zeitschrift fuer Naturforschung, B: A Journal of Chemical Sciences | ZNBSEN
Z. Naturforsch., C: J. Biosci. Zeitschrift fuer Naturforschung, C: Journal of Biosciences | ZNCBDA
Z. Phys. Chem. (Muenchen, Ger.) Zeitschrift fuer Physikalische Chemie (Muenchen, Germany) | ZPCFAX
Zhipu Xuebao | ZXHUBO
Zhongguo Shengwu Huaxue Yu Fenzi Shengwu Xuebao | ZSHXF2
Zhongguo Wuji Fenxi Huaxue | ZWFHAZ
Zh. Org. Farm. Khim. Zhurnal Organichnoi ta Farmatsevtichnoi Khimii | ZOFKAM

Contact CAS

Let us know how we can best serve you.

## Support Inquiry

Thanks for getting in touch. We look forward to helping you. The more information you provide, the faster we can connect you with our support team.

## Solutions & Services Inquiry

Thanks for your interest in CAS. We’re looking forward to connecting you with our team. Any information you provide will help us expedite your inquiry.

## General Inquiry or Comment

Thank you for contacting CAS, in order to connect you with the relevant teams or information, please tell us a little more about what you’re interested in. Any information you provide will help us expedite your inquiry.

### Related Training and Support

Training and Support

#### CAS Formulus: Using Formulation Designer to Create Novel Formulation Templates

Training and Support

#### CAS Formulus: Exploring the Advanced Search Functions

Training and Support

#### CAS Formulus: Ingredient Search Strategies to Fuel Formulations Search

## You May Also Be Interested In...

Training and Support

### CAS Formulus: Using Search and Filters to Research Formulations Faster

Read More
Training and Support

### CAS Formulus FAQ

Read More
Training and Support

### Academic Researcher FAQ

Read More
View More Training and Support